package com.ceb.gjjs.mda.global;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.ceb.gjjs.mda.bo.*;
import java.util.regex.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class Platform
{
		private static Logger log = LoggerFactory.getLogger(Platform.class);

        /**
        *   source:sysmod.@0000.script
        */
		public static String sdbCounter(String name)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getTableDB(name);
			return MdaUtils.format(Platform.mdbCounter(db,name),"00000000");
		}

        /**
        *   source:sysmod.@0001.script
        */
		public static String sdbCounter(IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			IDatafield<String> inr = (IDatafield)MdaDriver.getBaseObject(module,"inr");
			inr.setValue(Platform.sdbCounter(MdaDriver.getModuleType(module)));
			return inr.getValue();
		}

        /**
        *   source:sysmod.@0005.script
        */
		public static Argument addArgumentNotEmpty(String[] colnam,IDatafield... datafield)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Argument rlt = new Argument();
			for(int i=0;i<datafield.length;i++)
			{
			  if(!MdaUtils.isEmpty(datafield[i]))
			  {
			    rlt=rlt.and(colnam[i],EQ,datafield[i].getValue());
			  }
			}
			return rlt;
		}

        /**
        *   source:sysmod.@0002.script
        */
		public static int[] getChcTime(int total)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int a=total/3600;
			int b=(total%3600)/60;
			int c=total-a*3600-b*60;
			int temp[]=new int[3];
			temp[0]=a;
			temp[1]=b;
			temp[2]=c;
			return temp;
		}

        /**
        *   source:sysmod.@0003.script
        */
		public static Date formatDateTime(Date d,String hhmmss)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(d==null)
			  d=MdaUtils.today();
			if(MdaUtils.isEmpty(hhmmss)||hhmmss.equals("0"))
			  hhmmss="000000";
			String time = MdaUtils.format(d,"yyyyMMddHHmmss");
			time = time.substring(0,8);
			time = time+hhmmss;
			//log.debug(time);
			return MdaUtils.parseDate(time,"yyyyMMddHHmmss");
		}

        /**
        *   source:sysmod.@0008.script
        */
		public static void sdbRead(IModule mod,String inr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbRead(mod,new Argument<String>("inr",inr));
			int errorcode=ctx.getErrorCode();
			return;
		}

        /**
        *   source:sysmod.@0011.script
        */
		public static String sgetTransName()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String tn = ctx.getTransName();
			if(MdaUtils.isEmpty(tn))
			  return tn;
			int i = tn.indexOf(",");
			if(i>=0)
			{
			  tn = tn.substring(0,i);
			}
			return tn;
		}

        /**
        *   source:sysmod.@0012.script
        */
		public static String sgetTransParam()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String tn = ctx.getTransName();
			if(MdaUtils.isEmpty(tn))
			  return "";
			int i = tn.indexOf(",");
			if(i>=0)
			{
			  tn = tn.substring(i+1);
			}
			return tn;
		}

        /**
        *   source:sysmod.@0013.script
        */
		public static String sgetTransNameWithParam(String param)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String tn = Platform.sgetTransName();
			if(MdaUtils.isEmpty(param))
			{
			  return tn;
			}
			return tn+","+param;
		}

        /**
        *   source:sysmod.@0015.script
        */
		public static String sfixPreToken(String value,String token,int len)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//用指定字符从前填充字符串到指定长度
			// String value 要填充的字符串
			// String token 填充字符
			// int len 填充至长度
			if(len==0)
			  return value;
			if(MdaUtils.isEmpty(value))
			  value="";
			value=value.trim();
			if(value.length()>=len)
			  return value;
			StringBuffer sb = new StringBuffer(len);
			sb.append(value);
			for(int i=value.length();i<len;i++)
			{
			  sb.insert(0, token);
			}
			return sb.toString();
		}

        /**
        *   source:sysmod.@0017.script
        */
		public static boolean falseAndRollback()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbRollback();
			return false;
		}

        /**
        *   source:sysmod.@0018.script
        */
		public static boolean sdbLock(IModule mod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 1本方法直接对module模块加锁。
			// 2被加锁的模块不能是grp等数据集合只能是单表模块。
			// 3此模块inr中必须有值
			// 4此加锁方法按操作员登录名加锁，如果是系统服务启动时没有操作员不始于本方法。
			if(MdaUtils.isEmpty(mod))
			  return false;
			String db = Platform.getDefaultDB();
			IDatafield inrd = MdaDriver.getDatafield(mod,"inr");
			if(MdaUtils.isEmpty(inrd))
			  return false;
			if(Platform.checkFlgWithBussiness(db))
			{
			  String typ = MdaDriver.getModuleType(mod);
			  String inr = inrd.getValue().toString();
			  //log.debug("typ="+typ);
			  //log.debug("inr="+inr);
			  //log.debug("lockusr="+Platform.getLoginUser());
			  int errorCode = ctx.getErrorCode();
			  LockInfo l = Platform.mdbLock(MdaEnv.getLoginUser(),typ+inr);
			  //log.debug("lockinfo="+l);
			  errorCode = ctx.getErrorCode();
			  //log.debug("lock errcode="+errorCode);
			  if(errorCode != NO_ERROR)
			  {
			    if(errorCode==ERROR_LOCKED||errorCode==ERROR_LOCK)
			    {
			      log.debug("{}","记录已经被锁定");
			      return false;
			    }
			    else
			      log.debug("{}","lock errcode=" + errorCode);
			  }
			  return true;
			}
			else
			{
			  MdaUtils.exitRule();
				return false;
			}
		}

        /**
        *   source:sysmod.@0019.script
        */
		public static boolean sdbUnLock(IModule mod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(mod))
			  return false;
			IDatafield inrd = MdaDriver.getDatafield(mod,"inr");
			if(MdaUtils.isEmpty(inrd))
			  return false;
			String db = Platform.getDefaultDB();
			if(Platform.checkFlgWithBussiness(db))
			{
			  String typ = MdaDriver.getModuleType(mod);
			  String inr = inrd.getValue().toString();
			  //log.debug("unlk typ="+typ);
			  //log.debug("unlk inr="+inr);
			  //log.debug("unlk lockusr="+Platform.getLoginUser());
			  Platform.mdbUnlock(MdaEnv.getLoginUser(),typ+inr);
			  return true;
			}
			else
			{
			  MdaUtils.exitRule();
				return false;
			}
		}

        /**
        *   source:sysmod.@0021.script
        */
		public static String sdbInsert(IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String inr = Platform.sdbCounter(module);
			Platform.mdbInsert(module);
			return inr;
		}

        /**
        *   source:sysmod.@0022.script
        */
		public static Argument addStringArgumentOfLIKE(String[] colnam,IDatafield... datafield)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Argument rlt = new Argument();
			for(int i=0;i<datafield.length;i++)
			{
			  if(!MdaUtils.isEmpty(datafield[i]))
			  {
			    rlt=rlt.and(colnam[i],LIKE,"%" + datafield[i] + "%");
			  }
			}
			return rlt;
		}

        /**
        *   source:sysmod.@0023.script
        */
		public static void addError(IDatafield idf,String errcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *传一个IDatafield，错误代码。如果错误码为空或为0则返回，否则判断IDatafield是否已经存在该错误，没有则添加
			  */
			if(MdaUtils.isEmpty(errcod) || "0".equals(errcod))
			  return;
			String err = "";
			if(idf.getValue()!=null)
			{
			  err = idf.getValue().toString();
			  if("0".equals(err))
			  {
			    err = "";
			  }
			}
			if(!err.contains(errcod))
			  err += errcod;
			log.info("{}","@@@@Error Code.................:"+errcod);
			idf.setValue(err);
		}

        /**
        *   source:sysmod.@0024.script
        */
		public static String transnullString(String str)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(str))
			{
			  return "";
			}
			else
			{
			  return str;
			}
		}

        /**
        *   source:sysmod.@0025.script
        */
		public static void removeError(IDatafield idf,String errcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *传一个IDatafield，错误代码。从该错误字段中移除错误代码
			  */
			if(MdaUtils.isEmpty(errcod) || MdaUtils.isEmpty(idf)||MdaUtils.isEmpty(idf.getValue()))
			  return;
			String err = idf.getValue().toString();
			idf.setValue(err.replaceAll(errcod,""));
			log.debug("{}","remove Error Code.................:"+errcod);
		}

        /**
        *   source:sysmod.@0026.script
        */
		public static boolean equalsIgnore(String source,String target,boolean digitalOnly)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(source))
			  return false;
			if(MdaUtils.isEmpty(target))
			  return false;
			if(digitalOnly)
			{
			  source=source.replaceAll("\\D", "");
			  target=target.replaceAll("\\D", "");
			}
			else
			{
			  source=source.replaceAll("[^a-zA-Z0-9]", "");
			  target=target.replaceAll("[^a-zA-Z0-9]", "");
			}
			return source.equalsIgnoreCase(target);
		}

        /**
        *   source:sysmod.@0027.script
        */
		public static String format4Equals(String value, boolean digitalOnly)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(value))
			  return "";
			if(digitalOnly)
			{
			  return value.replaceAll("\\D", "");
			}
			else
			  return value.replaceAll("[^a-zA-Z0-9]", "").toLowerCase();
		}

        /**
        *   source:sysmod.@0028.script
        */
		public static List<CodetableItem> getMtyList()//获取系统维护的报文类型下拉列表
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//得到所有报文类型名称
			List<CodetableItem> mtyList = new ArrayList<CodetableItem>();//构造码表mtyList
			Platform.mdbExecuteSQL("SELECT mty FROM mfd WHERE tno=1 AND mty LIKE 'MT%' ORDER BY mty");//执行sql语句查询记录
			Argument<String> nam = new Argument<String>("mty");//构造Label列nam
			while(true)
			{
			  Platform.mdbFetchFields(nam);//逐条取出记录
			  int errorCode = ctx.getErrorCode();//取出记录的执行结果
			  if(errorCode == NO_ERROR)
			  {
			    String mtyval = nam.value;
			    if(!MdaUtils.isEmpty(mtyval)&&mtyval.length()>4)
			    {
			      mtyval = mtyval.substring(3);
			      mtyList.add(new CodetableItem(mtyval,mtyval));
			    }
			  }
			  else
			  {
			    break;
			  }
			}
			Platform.mdbCloseCursor();
			return mtyList;
		}

        /**
        *   source:sysmod.@0031.script
        */
		public static boolean transAndCheckBIC(IDatafield df)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	BIC输入转化好检查（BIC输入自动小写转大写，并作合法性检验）
			  * 1,将输入bic转化为大写
			  * 2,位数检查，不是4、8和11位的输入报错	位数不对返回2
			  * 3,位数正确查询数据库中是否存在此BIC	不合法返回3
			  * 4,完全合法返回1
			  -	df 检查的输入域
			  - bic	检查的输入值
			  */
			if(MdaUtils.isEmpty(df))
			{
			  return false;
			}
			String bic = (String)df.getValue();
			log.debug("{}","transAndCheckBIC: "+bic);
			if(!bic.matches("[0-9A-Za-z]*"))
			{
			  ctx.setFieldError(df,MdaUtils.getI18NString("sysmod","CT000104"));
			  return false;
			}
			///小写转大写
			String biccopy = bic.toUpperCase();
			int length = biccopy.length();
			///位数检查
			if(length == 11 || length == 8 ||length == 4)
			{
			  if(length == 8)
			  {
			    biccopy += "XXX";
			  }
			  if(length == 4)
			  {
			    biccopy += "XXXXXXX";
			  }
			  ///合法性检查
			  Argument<String> inrarg = new Argument<String>("inr");
			  String sql = "SELECT inr FROM pty WHERE extkey = '" + biccopy + "' "+
			    "AND ptytyp LIKE '%B%'";
			  Platform.mdbExecuteSQL(sql);
			  Platform.mdbFetchFields(inrarg);
			  Platform.mdbCloseCursor();
			  if(ctx.getErrorCode() == NO_ERROR)
			  {
			    df.setValue(biccopy);
			    
			    return true;
			  }
			  else
			  {
			    ///bic不存在
			    ctx.setFieldError(df,MdaUtils.getI18NString("sysmod","CT000105"));
			    return false;
			  }
			}
			else
			{
			  ctx.setFieldError(df,MdaUtils.getI18NString("sysmod","CT000156"));
			  return false;
			}
		}

        /**
        *   source:sysmod.@0033.script
        */
		public static void transAndCheckRef(IDatafield df)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	参考号的自动小写转大写，以及格式检查
			  */
			if(MdaUtils.isEmpty(df))
			{
			  return;
			}
			String ref = (String)df.getValue();
			if(!ref.matches("[0-9a-zA-Z /-?().,’+{}]*"))
			{
			  ctx.setFieldError(df,MdaUtils.getI18NString("sysmod","CT000144"));
			}
			else
			{
			  ref = ref.toUpperCase();
			  df.setValue(ref);
			  
			}
		}

        /**
        *   source:sysmod.@0034.script
        */
		public static String getLogicalTerminalAddress(String bic)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(bic))
			  return null;

			if(bic.length() == 8 || bic.length() == 11 || bic.length() == 12)
			{
			  //判断是否使用测试BIC码
			  if(! Platform.isUsingTestBicCode())
			  {
			    if (bic.length() == 11)
			    {
			      return bic.substring(0, 8) + "X" + bic.substring(8, 11);
			    }
			    else if (bic.length() == 8)
			    {
			      return bic.substring(0, 8) + "XXXX";
			    }
			    else
			      return bic;
			  }
			  else
			  {
			    if (bic.length() == 11)
			    {
			      return bic.substring(0, 7) + "0X" + bic.substring(8, 11);
			    }
			    else if (bic.length() == 8)
			    {
			      return bic.substring(0, 7) + "0XXXX";
			    }
			    else
			      return bic.substring(0, 7) + "0" + bic.substring(8);
			  }
			}
			else
			  return null;
		}

        /**
        *   source:sysmod.@0035.script
        */
		public static String gerner202Ref(String syscod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  传入 syscod，查询去其编号生成规则
			  根据202ref生成规则来生成ref
			  维护交易维护202ref生成规则，共16位规则
			  */
			return null;
		}

        /**
        *   source:sysmod.@0036.script
        */
		public static String changeCurToNum(String cur)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String sql = "SELECT numcod FROM cur WHERE cur=?";
			Argument<String> curArg = new Argument<String>("numcod");
			Object session = Platform.esdbExecuteSQL("eibs",sql,cur);
			Platform.esdbFetchFields(session,curArg);
			if(ctx.getErrorCode()== NO_ERROR)
			{
			  Platform.esdbCloseCursor(session);
			  return curArg.value;
			}
			else
			{
			  Platform.esdbCloseCursor(session);
			  return null;
			}
		}

        /**
        *   source:sysmod.@0037.script
        */
		public static String getPropertyValues(String propertyPath,String key)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String value = "";
			value = MdaUtils.getPropertyValue(propertyPath,key);
			if(MdaUtils.isEmpty(value))
			  value = "";
			log.debug("{}",key + ":" + value);
			return value;
		}

        /**
        *   source:sysmod.@0038.script
        */
		public static String getAccountDate()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 获取当前会计日期
			  - 无
			  @ Date 当前会计日期 YYYYMMDD 格式
			  */
			Argument<String> accountDate = new Argument<String>("accdat");
			String sqlQuery = "SELECT accdat FROM dat";
			Object session =  Platform.esdbExecuteSQL("eibs",sqlQuery);
			Platform.esdbFetchFields(session,accountDate);
			int errorcode = ctx.getErrorCode();
			Platform.esdbCloseCursor(session);
			if(errorcode != NO_ERROR)
			{
			  log.error("{}","getAccountDate with errorcode:" + errorcode);
			  return MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			}
			else
			{
			  String val = accountDate.value;
			  if(val == null)
			  {
			    log.error("{}","getAccountDate is null,return today.");
			    return MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			  }
			  else
			  {
			    log.debug("{}","获取会计日期："+val);
			    return val;
			  }
			}
		}

        /**
        *   source:sysmod.@0039.script
        */
		public static String sdbBopCounter(String name)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return MdaUtils.format(Platform.mdbCounter(name),"00");
		}

        /**
        *   source:sysmod.@0040.script
        */
		public static void disableModule(IModule im,List<String> exp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *灰显一个模型的不包含exp在内的所有字段
			  -im 要灰显的模块
			  -exp 不要灰显的字段列表
			  @无
			  */
			Object[] idfs = im.getDatafields().toArray();
			for(Object idf:idfs)
			{
			  IDatafield idfC = (IDatafield)idf;
			  String idfNam = idfC.getName();
			  if(exp != null && exp.contains(idfNam))
			    continue;
			  
			  
			}
		}

        /**
        *   source:sysmod.@0041.script
        */
		public static void enableModule(IModule im,List<String> exp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *亮显一个模型的不包含exp在内的所有字段
			  -im 要亮显的模块
			  -exp 不要亮显的字段列表
			  @无
			  */
			Object[] idfs = im.getDatafields().toArray();
			for(Object idf:idfs)
			{
			  IDatafield idfC = (IDatafield)idf;
			  String idfNam = idfC.getName();
			  if(exp != null && exp.contains(idfNam))
			    continue;
			  
			  
			}
		}

        /**
        *   source:sysmod.@0044.script
        */
		public static String getControlValue(String key)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(key == null)
			  return null;
			String sql = "SELECT val FROM ctl WHERE key = ?";
			Object session = Platform.esdbExecuteSQL("eibs",sql,key);
			Argument<String> val = new Argument<String>("val");
			String valStr=null;
			Platform.esdbFetchFields(session,val);
			if(ctx.getErrorCode() == NO_ERROR)
			{
			  valStr = val.value;
			}
			Platform.esdbCloseCursor(session);
			return valStr;
		}

        /**
        *   source:sysmod.@0048.script
        */
		public static void writeUserLog(IModule userLogModule,String userName,String operationName,String operationStatus)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 写入用户操作日志
			  @ userLogModule usrlog模块
			  @ userName 操作用户
			  @ operationName 操作描述
			  @ operationStatus 操作状态 S - 成功, E - 失败
			  - 无
			  */
			MdaUtils.clear(userLogModule);
			IDatafield field = MdaDriver.getDatafield(userLogModule,"nam");
			field.setValue(userName);
			field = MdaDriver.getDatafield(userLogModule,"oprnam");
			field.setValue(operationName);
			field = MdaDriver.getDatafield(userLogModule,"sta");
			field.setValue(operationStatus);
			field = MdaDriver.getDatafield(userLogModule,"oprdattim");
			field.setValue(MdaUtils.today());
			Platform.sdbInsert(userLogModule);
			int errorcode = ctx.getErrorCode();
			log.debug("{}","writeUserLog:[" + userName + "," + operationName + "] in status:" + operationStatus + " with errorcode:" + errorcode);
		}

        /**
        *   source:sysmod.@0056.script
        */
		public static String getFirstRegStr(String reg,String str)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*将符合正则表达式的第一个字串内容返回*/
			if(str == null)
			  return null;
			Matcher m = Pattern.compile(reg).matcher(str);
			if(m.find())
			  return m.group();
			else
			  return null;
		}

        /**
        *   source:sysmod.@0073.script
        */
		public static Object getDatabaseValue(String tableName,String fieldName,String whereFieldName,Object whereFieldValue)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String sql = "SELECT " + fieldName + " FROM " + tableName + " WHERE " + whereFieldName + " = ? ";
			int errorcode = ctx.getErrorCode();
			Argument arg = new Argument(fieldName);
			Platform.mdbExecuteSQL(sql,whereFieldValue);
			Platform.mdbFetchFields(arg);
			Platform.mdbCloseCursor();
			return arg.value;
		}

        /**
        *   source:sysmod.@0074.script
        */
		public static void disableDatafield(IDatafield datafield)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			
			
		}

        /**
        *   source:sysmod.@0075.script
        */
		public static void enableDatafield(IDatafield datafield)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			
			
		}

        /**
        *   source:sysmod.@0076.script
        */
		public static void clearDatafield(IDatafield datafield)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(datafield);
			
		}

        /**
        *   source:sysmod.@0077.script
        */
		public static IAttributeValue []  createStreamGridHeader(String [] titles,ViewType [] viewTypes,int [] lengths)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(titles.length != viewTypes.length || titles.length != lengths.length || viewTypes.length != lengths.length)
			{
			  log.debug("{}","createStreamGridHeader 3个数组参数长度不一致.");
			  return null;
			}
			int length = titles.length;
			IAttributeValue [] attrValues = new IAttributeValue[length];
			for(int i = 0 ; i < length ; i++)
			{
			  attrValues[i] = new AttributeValue(titles[i]);
			  
			}
			return attrValues;
		}

        /**
        *   source:sysmod.@0079.script
        */
		public static String getKtpCodetableLabel(String ktpNo)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Argument<String> ktpName = new Argument<String>("ktpnam");
			Platform.mdbExecuteSQL("SELECT KTPNAM FROM KTP WHERE KTPNO = ?",ktpNo);
			Platform.mdbFetchFields(ktpName);//逐条取出记录
			int errorCode = ctx.getErrorCode();//取出记录的执行结果
			Platform.mdbCloseCursor();
			if(MdaUtils.isEmpty(ktpName.value))
			  return "";
			else
			  return ktpName.value;
		}

        /**
        *   source:sysmod.@0083.script
        */
		public static String getCurrentChn(String mps)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);//获取当前渠道
			if(MdaUtils.isEmpty(mps))
			  return null;
			ctx.getErrorCode();
			String sql="SELECT E.CHNCOD COD FROM MPE E WHERE E.MPSINR='"+mps+"' ORDER BY E.INR";
			Argument cod=new Argument<String >("COD");
			List codlst=new ArrayList();
			Platform.mdbExecuteSQL(sql);
			while(true)
			{
			  Platform.mdbFetchFields(cod);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    codlst.add(cod.value);
			  }
			  else break;
			}
			Platform.mdbCloseCursor();
			if(codlst==null)
			  return null;
			return (String)codlst.get(0);
		}

        /**
        *   source:sysmod.@0084.script
        */
		public static String getUilCN()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return "zh_CN";
		}

        /**
        *   source:sysmod.@0085.script
        */
		public static String [] getCodetableKeyset(List<CodetableItem> ctl)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String [] keysets = new String[ctl.size()];
			for(int i = 0;i<ctl.size();i++)
			{
			  CodetableItem cti = ctl.get(i);
			  keysets[i] = cti.getValue();
			}
			return keysets;
		}

        /**
        *   source:sysmod.@0086.script
        */
		public static String getListCodetableLabel(List<CodetableItem> ctl,String value)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			for(int i = 0;i<ctl.size();i++)
			{
			  CodetableItem cti = ctl.get(i);
			  if(cti.getValue().equals(value))
			    return cti.getLabel();
			}
			return "";
		}

        /**
        *   source:sysmod.@0087.script
        */
		public static List<Object> getModuleDatafieldsValue(IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<Object> contentList = new ArrayList<Object>();
			java.lang.reflect.Field[] fields = module.getClass().getDeclaredFields();
			log.debug("{}","datafields size:" + fields.length);
			for(int i=0;i<fields.length;i++)
			{
			  try
			  {
			    Object obj = fields[i].get(module);
			    if(!(obj instanceof IDatafield))
			    {
			      contentList.add("");
			      continue;
			    }
			    IDatafield datafield = (IDatafield)obj;
			    log.debug("{}",fields[i].getName() + ":" + datafield.getValue());
			    contentList.add(datafield.getValue());
			  }
			  catch(Exception e)
			  {
			    log.error("{}",e);
			    continue;
			  }
			}
			log.debug("{}","contentList size:" + contentList.size());
			return contentList;
		}

        /**
        *   source:sysmod.@0088.script
        */
		public static Argument [] setModuleDatafieldsValue(IModule module,List<Object> contentList)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			java.lang.reflect.Field[] fields = module.getClass().getDeclaredFields();
			//Argument [] arguments = new Argument[fields.length];
			List<Argument> arguments = new ArrayList<Argument>();
			log.debug("{}","datafield size:" + fields.length);
			log.debug("{}","contentList size:" + contentList.size());
			for(int i=0;i<fields.length;i++)
			{
			  try
			  {
			    Object obj = fields[i].get(module);
			    if(!(obj instanceof IDatafield))
			      continue;

			    if(!MdaUtils.isEmpty(contentList.get(i)))
			    {
			      log.debug("{}",fields[i].getName() + ":" + contentList.get(i));
			      Argument argument = new Argument(fields[i].getName(),contentList.get(i));
			      arguments.add(argument);
			    }
			  }
			  catch(Exception e)
			  {
			    log.error("{}",e);
			    continue;
			  }
			}
			Argument [] argList = new Argument[arguments.size()];
			for(int i = 0;i < arguments.size();i++)
			  argList[i] = arguments.get(i);
			return argList;
		}

        /**
        *   source:sysmod.@0089.script
        */
		public static boolean clears(Object obj)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);//这个函数为配合新的clear（）函数而设计的，是对clear函数的一种多态设计
			if (obj == null)
			  return true;
			if (obj instanceof IModule)
			{
			  IModule imod=(IModule)obj;
			  imod.clear();
			}
			else
			  if (obj instanceof IModuleList)
			{
			  IModuleList imodlst=(IModuleList)obj;
			  if(MdaUtils.isEmpty(imodlst))
			    return false;
			  int sz=imodlst.size() - 1;
			  log.info("{}","imodlst size "+sz+1);
			  for(int i=sz;i>=0;i--)
			  {
			    imodlst.remove(i);
			  }
			  return true;
			}
			else
			{
			  return false;
			}
			return true;
		}

        /**
        *   source:sysmod.@0090.script
        */
		public static String getValidBicCode(String bic)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(bic))
			  return "";

			if(! bic.matches("[0-9A-Za-z]*"))
			  return "";

			bic = bic.toUpperCase();
			///位数检查
			if(bic.length() == 11)
			{
			  return bic;
			}
			else if(bic.length() == 8)
			{
			  return bic += "XXX";
			}
			else
			  return "";
		}

        /**
        *   source:sysmod.@0093.script
        */
		public static String getInterfaceSequence(String interfaceName,String sector)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			interfaceName = interfaceName.toUpperCase();
			sector = sector.toUpperCase();
			String ownSystemCode = "99306";
			String month = MdaUtils.format(MdaUtils.today(),"yyMM");
			String sequenceName = interfaceName + sector + month;
			String sequenceNumber = null;
			if("QS|QA|FA|NQ".contains(sector))
			{
			  String hstnam = Platform.getHostName();
			  String typ = "X";
			  if(!MdaUtils.isEmpty(hstnam))
			    typ = hstnam.substring(0,1).toUpperCase();
			  if(Platform.checkFlgWithBussiness("erd"))
			    sequenceNumber = typ + Platform.esdbCounter("erd",sequenceName,"00000");
			  else
			    sequenceNumber = typ + "X" + Platform.csdbCounter("erd",sequenceName,"0000");
			}
			else
			  sequenceNumber = Platform.sdbCounter(sequenceName,"000000");
			return ownSystemCode + sector + month + sequenceNumber;
		}

        /**
        *   source:sysmod.@0094.script
        */
		public static String sdbCounter(String name,String pattern)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return MdaUtils.format(Platform.mdbCounter(name),pattern);
		}

        /**
        *   source:sysmod.@0095.script
        */
		public static String getLogicInterfaceSequence(String sector)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return Platform.getInterfaceSequence("LJJZ",sector);
		}

        /**
        *   source:sysmod.@0096.script
        */
		public static Map<String,Object> callLogicInterface(Map<String,Object> map)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Map<String,Object> returnMap = (Map<String,Object>)MdaUtils.invoke("cn.com.brilliance.psbc.util.TexudoUtil","SendMessage",map);

			return returnMap;
		}

        /**
        *   source:sysmod.@0097.script
        */
		public static Map<String,Object> getOwnerNameByAccountInterface(String account)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(account))
			  return null;

			Map<String,Object> map = new HashMap<String,Object>();

			//交易类型码
			if(account.startsWith("FT"))
			{
			  map.put("PCODE","633120");
			}
			else
			  map.put("PCODE","633050");
			//主账号/卡号
			map.put("ACCOUNT",account);
			//交易属性
			map.put("TRADEFLAG","0");
			//渠道标识
			map.put("CHNLNO","29");
			//流水号
			String seqno = Platform.getLogicInterfaceSequence("NQ");
			map.put("SEQNO",seqno);
			//本地时间
			map.put("LOCALTIME",MdaUtils.format(MdaUtils.today(),"hhmmss"));
			//本地日期
			map.put("LOCALDATE",MdaUtils.format(MdaUtils.today(),"yyyyMMdd"));
			//会计日期
			map.put("CLEARDATE",Platform.getAccountDate());
			//交易系统代码
			map.put("TRANSINST","99306000000");
			//发信系统代码
			map.put("SENDINST","99306000000");

			String trace = "99306000000"
			  +MdaUtils.format(MdaUtils.today(),"yyyyMMdd")
			  +seqno.substring(2);
			map.put("STD_SYS_TRACE_NO",trace);

			//接收系统代码
			map.put("DESTINST","99700010000");
			//交易机构代码/受卡方标识码，默认送总行机构码
			map.put("TRANBRANCH","11005293");
			//柜员号,默认送11位数字
			map.put("OPRCODE","99311005293");
			//MAC
			map.put("MAC","8C30A0J1");

			Map<String,Object> returnMap = Platform.callLogicInterface(map);
			return returnMap;
		}

        /**
        *   source:sysmod.@0098.script
        */
		public static void convertString2IStream(String str,IStream is)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*try
			  {
			  is.getOutputStream().write(str.getBytes());
			  is.getOutputStream().flush();
			  }
			  catch(Exception e)
			  {
			  log.error(e);
			  }*/
			convertString2IStream(str,is,"utf-8");
		}

        /**
        *   source:sysmod.@0099.script
        */
		public static String convertIStream2String(IStream is)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return convertIStream2String(is,"utf-8");
		}

        /**
        *   source:sysmod.@0100.script
        */
		public static BigDecimal roundDecimal(BigDecimal bigDecimal,int round)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return bigDecimal.setScale(round, java.math.BigDecimal.ROUND_HALF_UP);
		}

        /**
        *   source:sysmod.@0102.script
        */
		public static boolean datafieldIsEmpty(IDatafield datafield)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(datafield == null)
			  return true;
			else
			{
			  if(MdaUtils.isEmpty(datafield))
			    return true;
			  else
			    return false;
			}
		}

        /**
        *   source:sysmod.@0103.script
        */
		public static void copyValueExceptInListField(IModule src,IModule dst,List<String> exp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(exp == null)
			  dst.copyValue(src);
			else
			{
			  Object[] srcdfs = src.getDatafields().toArray();
			  for(Object sidf:srcdfs)
			  {
			    IDatafield sidfv = (IDatafield)sidf;
			    String sdfNam = sidfv.getName();
			    if(exp.contains(sdfNam))
			      continue;
			    Object[] dstdfs = dst.getDatafields().toArray();
			    for(Object didf:dstdfs)
			    {
			      IDatafield didfv = (IDatafield)didf;
			      String ddfNam = didfv.getName();
			      if(ddfNam.equals(sdfNam))
			        didfv.setValue(sidfv.getValue());
			    }
			  }
			}
		}

        /**
        *   source:sysmod.@0104.script
        */
		public static Date getAccountDateTime()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String date = Platform.getAccountDate();
			String time = MdaUtils.format(MdaUtils.today(),"HHmmss");
			date = date + " " + time;
			return MdaUtils.parseDate(date,"yyyyMMdd HHmmss");
		}

        /**
        *   source:sysmod.@0105.script
        */
		public static String getPropertys(String propertyPath,String key)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String value = "";
			value = MdaUtils.getPropertyValue(propertyPath,key);
			if(MdaUtils.isEmpty(value))
			  value = "";
			log.debug("{}",key + ":" + value);
			return value;
		}

        /**
        *   source:sysmod.@0106.script
        */
		public static boolean isUsingTestBicCode()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String propertyPath = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"cfg");
			propertyPath = MdaUtils.catPath(propertyPath,"rcvsndmsg.properties");
			String propertyValue = Platform.getPropertys(propertyPath,"BankPostalUsingTestBic");
			if(! MdaUtils.isEmpty(propertyValue))
			  return true;
			else
			  return false;
		}

        /**
        *   source:sysmod.@0107.script
        */
		public static String getBeforeAccountDate()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 获取前一会计日期
			  - 无
			  @ Date 前一会计日期 YYYYMMDD 格式
			  */
			Argument<String> accountDate = new Argument<String>("befdat");
			String sqlQuery = "SELECT befdat FROM dat";
			Object session = Platform.esdbExecuteSQL("eibs",sqlQuery);
			Platform.esdbFetchFields(session,accountDate);
			int errorcode = ctx.getErrorCode();
			Platform.esdbCloseCursor(session);
			if(errorcode != NO_ERROR)
			{
			  log.error("{}","getBeforeAccountDate with errorcode:" + errorcode);
			  return MdaUtils.format(MdaUtils.add(MdaUtils.parseDate(Platform.getAccountDate(),"yyyyMMdd"),-1),"yyyyMMdd");
			}
			else
			{
			  String val = accountDate.value;
			  if(val == null)
			  {
			    log.error("{}","getBeforeAccountDate is null,return accountDate - 1.");
			    return MdaUtils.format(MdaUtils.add(MdaUtils.parseDate(Platform.getAccountDate(),"yyyyMMdd"),-1),"yyyyMMdd");
			  }
			  else
			  {
			    log.debug("{}","获取前一会计日期："+val);
			    return val;
			  }
			}
		}

        /**
        *   source:sysmod.@0108.script
        */
		public static String leftPad(String source,String charPad,int fullLength)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//如果字符串是空
			if(MdaUtils.isEmpty(source))
			{
			  String padStr = "";
			  for(int i = 0;i<fullLength;i++)
			    padStr += charPad;

			  return padStr;
			}
			else
			{
			  int length = fullLength - source.length();
			  if(length <= 0)
			    return source;
			  else
			  {
			    String padStr = "";
			    for(int i = 0;i<length;i++)
			      padStr += charPad;

			    return padStr + source;
			  }
			}
		}

        /**
        *   source:sysmod.@0110.script
        */
		public static String rightPad(String source,String charPad,int fullLength)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//如果字符串是空
			if(MdaUtils.isEmpty(source))
			{
			  String padStr = "";
			  for(int i = 0;i<fullLength;i++)
			    padStr += charPad;

			  return padStr;
			}
			else
			{
			  int length = fullLength - source.length();
			  if(length <= 0)
			    return source;
			  else
			  {
			    String padStr = "";
			    for(int i = 0;i<length;i++)
			      padStr += charPad;

			    return source + padStr;
			  }
			}
		}

        /**
        *   source:sysmod.@0111.script
        */
		public static Argument<Date> getDateEqualArgument(String columnName,Date date)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Argument<Date> arg = new Argument<Date>(columnName,GE,MdaUtils.sqlDate(date,GE));
			arg = arg.and(new Argument<Date>(columnName,LE,MdaUtils.sqlDate(date,LE)));

			return arg;
		}

        /**
        *   source:sysmod.@0112.script
        */
		public static String replaceCharacter(String charac)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(charac))
			  return "";
			return charac.replaceAll("\\D", "");
		}

        /**
        *   source:sysmod.@0115.script
        */
		public static List<CodetableItem> getFMtyList()//获取系统维护的报文类型下拉列表
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//得到所有报文类型名称
			List<CodetableItem> mtyList = new ArrayList<CodetableItem>();//构造码表mtyList
			Platform.mdbExecuteSQL("SELECT mty FROM mfd WHERE tno=1 AND mty LIKE 'FMT%' ORDER BY mty");//执行sql语句查询记录
			Argument<String> nam = new Argument<String>("mty");//构造Label列nam
			while(true)
			{
			  Platform.mdbFetchFields(nam);//逐条取出记录
			  int errorCode = ctx.getErrorCode();//取出记录的执行结果
			  if(errorCode == NO_ERROR)
			  {
			    String mtyval = nam.value;
			    if(!MdaUtils.isEmpty(mtyval)&&mtyval.length()>5)
			    {
			      mtyval = mtyval.substring(4);
			      mtyList.add(new CodetableItem(mtyval,mtyval));
			    }
			  }
			  else
			  {
			    break;
			  }
			}
			Platform.mdbCloseCursor();
			return mtyList;
		}

        /**
        *   source:sysmod.@0121.script
        */
		public static String getCfgPropertyValue(String propertiesName,String key)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String propertyPath = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"cfg");
			propertyPath = MdaUtils.catPath(propertyPath,propertiesName);
			log.debug("{}","propertyPath:"+propertyPath);
			return MdaUtils.getPropertyValue(propertyPath,key);
		}

        /**
        *   source:sysmod.@0124.script
        */
		public static String getRelStbtbl(String stbtbl,String etyinr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String rtn = "";
			String sql = "SELECT tbl FROM sth WHERE tbl LIKE '"+stbtbl+"%' ";
			if("00000001".equals(etyinr))
			{
			  sql = sql + " AND ( etyinr = '"+etyinr+"' OR etyinr is null ) ";
			}
			else
			  sql = sql + " AND etyinr = '"+etyinr+"' ";
			ctx.getErrorCode();
			Platform.mdbExecuteSQL(sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  Argument<String> tbl = new Argument<String>("tbl");
			  Platform.mdbFetchFields(tbl);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    rtn = tbl.value;
			  }
			  Platform.mdbCloseCursor();
			}
			return rtn;
		}

        /**
        *   source:sysmod.@0137.script
        */
		public static Object getStoredData(String key)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Object value = ctx.restoreData(key);
			if(value!=null)
			  ctx.storeData(key,value);
			return value;
		}

        /**
        *   source:sysmod.@0138.script
        */
		public static String getModuleDB(IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Object mapObj = getStoredData("DbMap");
			if(mapObj==null)
			{
			  String path = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"WEB-INF/classes");
			  mapObj = MdaUtils.invoke("com.brilliance.xml.DbMapping","getMap",path);
			  ctx.storeData("DbMap",mapObj);
			}
			Map<String,String> map = (Map<String,String>)mapObj;
			String moduleClass = module.getClass().toString().substring(6);
			String db = map.get(moduleClass);
			if(db==null||db.contains(","))
			{
			  db=Platform.getDefaultDB();
			}
			log.trace("{}","getModuleDB "+module.getName()+" "+db);
			return db;
		}

        /**
        *   source:sysmod.@0140.script
        */
		public static void mdbBegin()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getDefaultDB();
			Platform.mdbBegin(db);
		}

        /**
        *   source:sysmod.@0141.script
        */
		public static void mdbBegin(String db)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//Platform.mdbConnect(db);
			ctx.getDaoSession().dbConnect(db);
			Platform.setLastDB(db);
			if(Platform.checkFlgWithBussiness(db))
			{
			  ctx.getDaoSession().dbBegin();
			  ctx.storeData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground(),db);
			}
			else
			{
			  //Platform.exitEvent();
			}
		}

        /**
        *   source:sysmod.@0142.script
        */
		public static void mdbConnect(String db)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String beginDB = (String)Platform.getStoredData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			if(beginDB==null)
			{
			  //log.debug("mdbconnect "+db);
			  ctx.getDaoSession().dbConnect(db);
			  Platform.setLastDB(db);
			}
		}

        /**
        *   source:sysmod.@0143.script
        */
		public static String getLastDB()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db=(String)Platform.getStoredData("LastDB."+Platform.getModuleRoot());
			if(db==null)
			{
			  db="eibs";
			}
			return db;
		}

        /**
        *   source:sysmod.@0144.script
        */
		public static void mdbConnect()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getDefaultDB();
			String beginDB = (String)Platform.getStoredData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			if(beginDB==null)
			{
			  //log.debug("mdbconnect "+db);
			  ctx.getDaoSession().dbConnect(db);
			  Platform.setLastDB(db);
			}
		}

        /**
        *   source:sysmod.@0145.script
        */
		public static void mdbCommit()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.restoreData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			ctx.getDaoSession().dbCommit();
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0146.script
        */
		public static void setLastDB(String db)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(db!=null)
			{
			  ctx.storeData("LastDB."+Platform.getModuleRoot(),db);
			}
		}

        /**
        *   source:sysmod.@0147.script
        */
		public static void mdbRollback()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.restoreData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			ctx.getDaoSession().dbRollback();
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0148.script
        */
		public static void mdbCloseCursor()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.getDaoSession().dbCloseCursor();
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0149.script
        */
		public static int mdbCounter(String counterName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = (String)Platform.getStoredData("BeginDB");
			if(db==null)
			  Platform.mdbConnect();
			else
			  Platform.mdbConnect(db);
			log.debug("{}","mdbcounter db : "+Platform.getCurrentDBName());
			int cnt ;
			try
			{
			  cnt =  ctx.getDaoSession().dbCounter(counterName);
			}
			catch(Exception e)
			{
			  Platform.sessionsReconect(MdaUtils.getDatasourceName());
			  cnt =  ctx.getDaoSession().dbCounter(counterName);
			}
			Platform.mdbDisconnect();
			return cnt;
		}

        /**
        *   source:sysmod.@0150.script
        */
		public static LockInfo mdbLock(String lockName,String lockStr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect();
			String sql = "select dattim,nam from lck where txt = ? ";
			Argument<Date> dattim = new Argument<Date>("dattim");
			Argument<String> nam = new Argument<String>("nam");
			List<String> arg = new ArrayList<String>();
			arg.add(lockStr);
			Platform.mdbExecuteSQL(sql,arg.toArray());
			Platform.mdbFetchFields(dattim,nam);
			int err = ctx.getErrorCode();
			//log.debug("err="+err);
			if(err==NO_ERROR)
			{
			  Platform.mdbCloseCursor();
			  LockInfo lockInfo = new LockInfo(dattim.value,nam.value);
			  ctx.setErrorCode(ERROR_LOCKED);
			  return lockInfo;
			}
			else
			{
			  Platform.mdbCloseCursor();
			  LockInfo lockInfo = null;
			  try
			  {
			    lockInfo = ctx.getLocker().lock(lockName,lockStr);
			  }
			  catch(Exception e)
			  {
			    Platform.sessionsReconect(MdaUtils.getDatasourceName());
			    lockInfo = ctx.getLocker().lock(lockName,lockStr);
			  }
			  Platform.mdbDisconnect();
			  return lockInfo;
			}
		}

        /**
        *   source:sysmod.@0151.script
        */
		public static void mdbUnlock(String lockName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect();
			try
			{
			  ctx.getLocker().unlock(lockName);
			}
			catch(Exception e)
			{
			  log.info("{}","Unlockmessage2:"+Platform.getCurrentDBName());
			  Platform.sessionsReconect(MdaUtils.getDatasourceName());
			  ctx.getLocker().unlock(lockName);
			}
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0152.script
        */
		public static void mdbExecuteSQLWithDb(String db,String sql)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbExecuteSQL(sql);
		}

        /**
        *   source:sysmod.@0153.script
        */
		public static void mdbExecuteSQL(String sql)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getDbFromSql(sql);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbExecuteSQL(sql);
		}

        /**
        *   source:sysmod.@0154.script
        */
		public static void mdbDelete(IModule module,Argument... argument)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//String db = (String)Platform.getStoredData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			//Platform.mdbConnect(db);
			ctx.getDaoSession().dbDelete(module,argument);
		}

        /**
        *   source:sysmod.@0155.script
        */
		public static void mdbDelete(IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//String db = (String)Platform.getStoredData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			//Platform.mdbConnect(db);
			ctx.getDaoSession().dbDelete(module);
		}

        /**
        *   source:sysmod.@0156.script
        */
		public static void mdbUnlock(String lockName,String lockStr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect();
			try
			{
			  ctx.getLocker().unlock(lockName,lockStr);
			}
			catch(Exception e)
			{
			  log.info("{}","Unlockmessage1:"+Platform.getCurrentDBName());
			  Platform.sessionsReconect(MdaUtils.getDatasourceName());
			  ctx.getLocker().unlock(lockName,lockStr);
			}
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0157.script
        */
		public static String getDefaultDB()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db=(String)Platform.getStoredData("DefaultDB."+Platform.getModuleRoot());
			if(db==null)
			{
			  //从前手交易获取默认数据库
			  String caller = (String)ctx.restoreData(ctx.getTransName()+".caller");
			  if(caller!=null)
			  {
			    String lastDB=(String)Platform.getStoredData("LastDB."+caller);
			    log.debug("{}","caller LastDB="+lastDB);
			    Platform.setLastDB(lastDB);
			    db=(String)Platform.getStoredData("DefaultDB."+caller);
			    log.debug("{}","caller DefaultDB="+db);
			    Platform.setDefaultDB(db);
			  }
			  else
			  {
			    String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"cfg/transdb.properties");
			    String trnnam = ctx.getTransName();
			    db = MdaUtils.getPropertyValue(fileName,trnnam);
			    if(!MdaUtils.isEmpty(db))
			      log.debug("{}",trnnam+" db = "+db);
			    if(MdaUtils.isEmpty(db) && trnnam.length()>6)
			    {
			      db = MdaUtils.getPropertyValue(fileName,trnnam.substring(0,6));
			      if(!MdaUtils.isEmpty(db))
			        log.debug("{}",trnnam.substring(0,6)+" db ="+db);
			    }
			    if(MdaUtils.isEmpty(db))
			    {
			      db = MdaUtils.getPropertyValue(fileName,trnnam.substring(0,3)+"***");
			      if(!MdaUtils.isEmpty(db))
			        log.debug("{}",trnnam.substring(0,3)+"***"+" db ="+db);
			    }
			    if(MdaUtils.isEmpty(db))
			    {
			      db = MdaUtils.getPropertyValue(fileName,trnnam.substring(0,2)+"****");
			      if(!MdaUtils.isEmpty(db))
			        log.debug("{}",trnnam.substring(0,2)+"****"+" db ="+db);
			    }
			    if(MdaUtils.isEmpty(db))
			    {
			      db = MdaUtils.getPropertyValue(fileName,"***"+trnnam.substring(3));
			      if(!MdaUtils.isEmpty(db))
			        log.debug("{}","***"+trnnam.substring(3)+" db ="+db);
			    }
			    if(MdaUtils.isEmpty(db))
			    {
			      db = MdaUtils.getPropertyValue(fileName,trnnam.substring(0,2)+"*"+trnnam.substring(3));
			      if(!MdaUtils.isEmpty(db))
			        log.debug("{}",trnnam.substring(0,2)+"*"+trnnam.substring(3)+" db ="+db);
			    }
			    if(!MdaUtils.isEmpty(db))
			    {
			      log.debug("{}","transdb.properties DefaultDB="+db);
			      Platform.setDefaultDB(db);
			    }
			    else
			    {
			      db="eibs";
			    }
			  }
			}
			return db;
		}

        /**
        *   source:sysmod.@0158.script
        */
		public static void setDefaultDB(String db)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(db!=null)
			{
			  ctx.storeData("DefaultDB."+Platform.getModuleRoot(),db);
			  log.debug("{}","DefaultDB change to "+db);
			}
		}

        /**
        *   source:sysmod.@0159.script
        */
		public static int mdbCounter(String db,String counterName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			log.debug("{}","mdbcounter db : "+Platform.getCurrentDBName());
			int cnt ;
			try
			{
			  cnt =  ctx.getDaoSession().dbCounter(counterName);
			}
			catch(Exception e)
			{
			  Platform.sessionsReconect(MdaUtils.getDatasourceName());
			  cnt =  ctx.getDaoSession().dbCounter(counterName);
			}
			Platform.mdbDisconnect();
			return cnt;
		}

        /**
        *   source:sysmod.@0160.script
        */
		public static LockInfo mdbLock(String db,String lockName,String lockStr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			String sql = "select dattim,nam from lck where txt = ? ";
			Argument<Date> dattim = new Argument<Date>("dattim");
			Argument<String> nam = new Argument<String>("nam");
			List<String> arg = new ArrayList<String>();
			arg.add(lockStr);
			Platform.mdbExecuteSQLWithDb(db,sql,arg.toArray());
			Platform.mdbFetchFields(dattim,nam);
			int err = ctx.getErrorCode();
			//log.debug("err="+err);
			if(err==NO_ERROR)
			{
			  Platform.mdbCloseCursor();
			  LockInfo lockInfo = new LockInfo(dattim.value,nam.value);
			  ctx.setErrorCode(ERROR_LOCKED);
			  return lockInfo;
			}
			else
			{
			  Platform.mdbCloseCursor();
			  LockInfo lockInfo = null;
			  try
			  {
			    lockInfo = ctx.getLocker().lock(lockName,lockStr);
			  }
			  catch(Exception e)
			  {
			    Platform.sessionsReconect(MdaUtils.getDatasourceName());
			    lockInfo = ctx.getLocker().lock(lockName,lockStr);
			  }
			  Platform.mdbDisconnect();
			  return lockInfo;
			}
		}

        /**
        *   source:sysmod.@0161.script
        */
		public static void mdbUnlockWithDb(String db,String lockName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			try
			{
			  ctx.getLocker().unlock(lockName);
			}
			catch(Exception e)
			{
			  Platform.sessionsReconect(MdaUtils.getDatasourceName());
			  ctx.getLocker().unlock(lockName);
			}
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0162.script
        */
		public static void mdbUnlockWithDb(String db,String lockName,String lockStr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.getDaoSession().dbConnect(db);
			try
			{
			  ctx.getLocker().unlock(lockName,lockStr);
			}
			catch(Exception e)
			{
			  Platform.sessionsReconect(MdaUtils.getDatasourceName());
			  ctx.getLocker().unlock(lockName,lockStr);
			}
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0163.script
        */
		public static void mdbFetchFields(IResult... result)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.getDaoSession().dbFetchFields(result);
		}

        /**
        *   source:sysmod.@0164.script
        */
		public static void mdbInsert(IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//String db = (String)Platform.getStoredData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			//Platform.mdbConnect(db);
			Platform.delCharTerm(module);
			ctx.getDaoSession().dbInsert(module);
		}

        /**
        *   source:sysmod.@0165.script
        */
		public static void mdbUpdate(IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//String db = (String)Platform.getStoredData("BeginDB."+getModuleRoot()+Platform.addThreadIdIfIsBackground());
			//Platform.mdbConnect(db);
			Platform.delCharTerm(module);
			ctx.getDaoSession().dbUpdate(module);
		}

        /**
        *   source:sysmod.@0166.script
        */
		public static void mdbRead(IModule module,Argument... arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getModuleDB(module);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbRead(module,arguments);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0167.script
        */
		public static void mdbRead(String db,IModule module,Argument... arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbRead(module,arguments);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0168.script
        */
		public static void mdbReadset(IModuleList list,Argument... arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getModuleListDB(list);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(list,arguments);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0169.script
        */
		public static String getModuleListDB(IModuleList list)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Object mapObj = getStoredData("DbMap");
			if(mapObj==null)
			{
			  String path = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"WEB-INF/classes");
			  mapObj = MdaUtils.invoke("com.brilliance.xml.DbMapping","getMap",path);
			  ctx.storeData("DbMap",mapObj);
			}
			Map<String,String> map = (Map<String,String>)mapObj;
			String listClass = list.getClass().toString().substring(6);
			String moduleClass = listClass.replace(".Elst",".");
			String db = map.get(moduleClass);
			log.trace("{}","getModuleListDB "+moduleClass+" "+db);
			if(db==null||db.contains(","))
			{
			  db=Platform.getDefaultDB();
			}
			return db;
		}

        /**
        *   source:sysmod.@0170.script
        */
		public static void mdbReadset(String db,IModuleList list,Argument... arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(list,arguments);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0171.script
        */
		public static void mdbReadset(IModuleList list,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getModuleListDB(list);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(list,whereClause,datas);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0172.script
        */
		public static void mdbReadset(String db,IModuleList list,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(list,whereClause,datas);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0173.script
        */
		public static void mdbReadset(IModuleList[] lists,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getModuleListsDB(lists);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(lists,whereClause,datas);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0174.script
        */
		public static String getModuleListsDB(IModuleList[] lists)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = null;
			for(IModuleList list:lists)
			{
			  db=Platform.getModuleListDB(list);
			  if(!"eibs".equals(db))
			    return db;
			}
			return db;
		}

        /**
        *   source:sysmod.@0175.script
        */
		public static void mdbReadset(String db,IModuleList[] lists,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(lists,whereClause,datas);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0176.script
        */
		public static void mdbReadset(IModuleList list,int maxSize,Argument... arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getModuleListDB(list);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(list,maxSize,arguments);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0177.script
        */
		public static void mdbReadset(String db,IModuleList list,int maxSize,Argument... arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(list,maxSize,arguments);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0178.script
        */
		public static void mdbReadset(IModuleList list,int maxSize,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getModuleListDB(list);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(list,maxSize,whereClause,datas);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0179.script
        */
		public static void mdbReadset(String db,IModuleList list,int maxSize,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(list,maxSize,whereClause,datas);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0180.script
        */
		public static void mdbReadset(IModuleList[] lists,int maxSize,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getModuleListsDB(lists);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbReadset(lists,maxSize,whereClause,datas);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0181.script
        */
		public static void mdbReadset(String db,IModuleList[] lists,int maxSize,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			int errorCode = ctx.getErrorCode();
			log.debug("{}","errorCode11 = "+errorCode);
			ctx.setErrorCode(errorCode);
			ctx.getDaoSession().dbReadset(lists,maxSize,whereClause,datas);
			errorCode = ctx.getErrorCode();
			log.debug("{}","errorCode12 = "+errorCode);
			ctx.setErrorCode(errorCode);
			Platform.mdbDisconnect();
		}

        /**
        *   source:sysmod.@0182.script
        */
		public static String sdbBopCounterWithDb(String db,String name)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return MdaUtils.format(Platform.mdbCounter(db,name),"00");
		}

        /**
        *   source:sysmod.@0183.script
        */
		public static String sdbCounterWithDb(String db,String name)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return MdaUtils.format(Platform.mdbCounter(db,name),"00000000");
		}

        /**
        *   source:sysmod.@0184.script
        */
		public static String sdbCounterWithDb(String db,IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			IDatafield<String> inr = (IDatafield)MdaDriver.getBaseObject(module,"inr");
			inr.setValue(Platform.sdbCounter(db,MdaDriver.getModuleType(module)));
			return inr.getValue();
		}

        /**
        *   source:sysmod.@0185.script
        */
		public static String sdbCounterWithDb(String db,String name,String pattern)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return MdaUtils.format(Platform.mdbCounter(db,name),pattern);
		}

        /**
        *   source:sysmod.@0186.script
        */
		public static boolean sdbLock(String db,IModule mod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 1本方法直接对module模块加锁。
			// 2被加锁的模块不能是grp等数据集合只能是单表模块。
			// 3此模块inr中必须有值
			// 4此加锁方法按操作员登录名加锁，如果是系统服务启动时没有操作员不始于本方法。
			if(MdaUtils.isEmpty(mod))
			  return false;
			IDatafield inrd = MdaDriver.getDatafield(mod,"inr");
			if(MdaUtils.isEmpty(inrd))
			  return false;
			if(Platform.checkFlgWithBussiness(db))
			{
			  String typ = MdaDriver.getModuleType(mod);
			  String inr = inrd.getValue().toString();
			  //log.debug("typ="+typ);
			  //log.debug("inr="+inr);
			  //log.debug("lockusr="+Platform.getLoginUser());
			  int errorCode = ctx.getErrorCode();
			  LockInfo l = Platform.mdbLock(db,MdaEnv.getLoginUser(),typ+inr);
			  //log.debug("lockinfo="+l);
			  errorCode = ctx.getErrorCode();
			  //log.debug("lock errcode="+errorCode);
			  if(errorCode != NO_ERROR)
			  {
			    if(errorCode==ERROR_LOCKED||errorCode==ERROR_LOCK)
			    {
			      log.debug("{}","记录已经被锁定");
			      return false;
			    }
			    else
			      log.debug("{}","lock errcode=" + errorCode);
			  }
			  return true;
			}
			else
			{
			  MdaUtils.exitRule();
				return false;
			}
		}

        /**
        *   source:sysmod.@0187.script
        */
		public static void sdbRead(String db,IModule mod,String inr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbRead(db,mod,new Argument<String>("inr",inr));
			int errorcode=ctx.getErrorCode();
			return;
		}

        /**
        *   source:sysmod.@0188.script
        */
		public static boolean sdbUnLockWithDb(String db,IModule mod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(mod))
			  return false;
			IDatafield inrd = MdaDriver.getDatafield(mod,"inr");
			if(MdaUtils.isEmpty(inrd))
			  return false;
			if(Platform.checkFlgWithBussiness(db))
			{
			  String typ = MdaDriver.getModuleType(mod);
			  String inr = inrd.getValue().toString();
			  //log.debug("unlk typ="+typ);
			  //log.debug("unlk inr="+inr);
			  //log.debug("unlk lockusr="+Platform.getLoginUser());
			  Platform.mdbUnlockWithDb(db,MdaEnv.getLoginUser(),typ+inr);
			  return true;
			}
			else
			{
			  MdaUtils.exitRule();
				return false;
			}
		}

        /**
        *   source:sysmod.@0189.script
        */
		public static void mdbExecuteSQL(String sql,Object... value)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = Platform.getDbFromSql(sql);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbExecuteSQL(sql,value);
		}

        /**
        *   source:sysmod.@0190.script
        */
		public static void mdbExecuteSQLWithDb(String db,String sql,Object... value)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbExecuteSQL(sql,value);
		}

        /**
        *   source:sysmod.@0191.script
        */
		public static String getDbFromSql(String orisql)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String tbl = null;
			String sql = orisql.toLowerCase();
			int idx = sql.indexOf("from");
			if(idx<=0)
			{
			  return Platform.getDefaultDB();
			}
			sql = sql.substring(idx+4).trim();
			sql=sql.trim();
			int idx1 = sql.indexOf(" ");
			int idx2 = sql.indexOf(",");
			if(idx1>0 && idx2>0)
			  idx = idx1>idx2 ? idx2 :
			idx1;
			else if(idx1>0)
			  idx = idx1;
			else if(idx2>0)
			  idx = idx2;
			else
			  idx = sql.length();
			tbl = sql.substring(0,idx).trim();
			tbl = "com.brilliance.eibs.etrade."+tbl.substring(0,1).toUpperCase()+tbl.substring(1);
			//log.debug("-------------------------tbl:"+tbl);
			Object mapObj = getStoredData("DbMap");
			if(mapObj==null)
			{
			  String path = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"WEB-INF/classes");
			  mapObj = MdaUtils.invoke("com.brilliance.xml.DbMapping","getMap",path);
			  ctx.storeData("DbMap",mapObj);
			}
			Map<String,String> map = (Map<String,String>)mapObj;
			// log.debug("------------------------Map:"+map);
			String db = map.get(tbl);
			if(db==null||db.contains(","))
			{
			  db=Platform.getDefaultDB();
			}
			//log.debug("-------------------------dbName:"+db);
			return db;
		}

        /**
        *   source:sysmod.@0195.script
        */
		public static void mchain(String name)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String defautDb =Platform.getDefaultDB();
			if("eibs".equals(defautDb))
			{
			  String db=(String)Platform.getStoredData("DefaultDB."+Platform.getModuleRoot());
			  if(db!=null)
			  {
			    ctx.storeData(name+".caller",Platform.getModuleRoot().toString());
			  }
			}
			else
			{
			  ctx.storeData(name+".caller",Platform.getModuleRoot().toString());
			}
			
		}

        /**
        *   source:sysmod.@0196.script
        */
		public static void mchain(String name,Boolean clearFlag,Boolean newTabFlag)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String defautDb =Platform.getDefaultDB();
			if("eibs".equals(defautDb))
			{
			  String db=(String)Platform.getStoredData("DefaultDB."+Platform.getModuleRoot());
			  if(db!=null)
			  {
			    ctx.storeData(name+".caller",Platform.getModuleRoot().toString());
			  }
			}
			else
			{
			  ctx.storeData(name+".caller",Platform.getModuleRoot().toString());
			}
			
		}

        /**
        *   source:sysmod.@0197.script
        */
		public synchronized static IModuleRoot getModuleRoot()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return (IModuleRoot)MdaDriver.getModule(null,"");
		}

        /**
        *   source:sysmod.@0200.script
        */
		public static List<CodetableItem> getCipsList()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//得到所有报文类型名称
			List<CodetableItem> mtyList = new ArrayList<CodetableItem>();//构造码表mtyList
			Platform.mdbExecuteSQL("SELECT mty FROM mfd WHERE tno=1 AND mty like 'cips%' ORDER BY mty");//执行sql语句查询记录
			Argument<String> nam = new Argument<String>("mty");//构造Label列nam
			while(true)
			{
			  Platform.mdbFetchFields(nam);//逐条取出记录
			  int errorCode = ctx.getErrorCode();//取出记录的执行结果
			  //log.error(errorCode);
			  if(errorCode==NO_ERROR)
			  {
			    String mtyval = nam.value;
			    //log.info(mtyval);
			    if(!MdaUtils.isEmpty(mtyval)&&mtyval.length()>4)
			    {
			      mtyval = mtyval.substring(5);
			      mtyList.add(new CodetableItem(mtyval,mtyval));
			    }
			  }
			  else
			  {
			    break;
			  }
			}
			Platform.mdbCloseCursor();
			return mtyList;
		}

        /**
        *   source:sysmod.@0202.script
        */
		public static void mstreamSave(IStream stream,String fileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  java.io.File file = new java.io.File(fileName);
			  if (!file.getParentFile().exists())
			  {
			    file.getParentFile().mkdirs();
			  }
			  try
			  {
			    org.sss.util.ContainerUtils.copy(stream.getInputStream(), new java.io.FileOutputStream(file));
			    stream.close();
			  }
			  catch(Exception e1)
			  {
			    log.error("{}","mstreamSave CopyOrClose error.");
			  }
			  //将文件上传到文件服务器
			  boolean rtn = Platform.fsUpload(fileName);
			  if(!rtn)
			  {
			    log.error("{}","mstreamSave fsUpload error.");
			  }
			}
			catch (Exception e)
			{
			  log.error("{}","mstreamSave error.", e);
			}
		}

        /**
        *   source:sysmod.@0194.script
        */
		public static boolean fsUpload(String fileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **将文件上传到文件服务器
			  **上传文件全路径--
			  **/
			boolean flg = false;
			flg = (Boolean)MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsUpload",fileName);
			log.info("{}","fileserver fsUpload status:"+flg);
			return flg;
		}

        /**
        *   source:sysmod.@0203.script
        */
		public static void mstreamLoad(IStream stream, String fileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//将文件内容写入stream流中
			try
			{
			  stream.close();
			  java.io.File file = null;
			  try
			  {
			    file = new java.io.File(fileName);
			    if(file != null && file.length() > 0)
			    {
			      log.info("{}","local file exists,trying streamLoad.");
			      org.sss.util.ContainerUtils.copy(new java.io.FileInputStream(file), stream.getOutputStream());
			    }
			    else
			    {
			      log.info("{}","local file unexists,trying streamLoad from fileserver.");
			      //从文件服务器下载文件
			      file = Platform.fsDownload(fileName);
			      if(file != null && file.length() > 0)
			      {
			        log.info("{}","fileserver exists,trying streamLoad.");
			        org.sss.util.ContainerUtils.copy(new java.io.FileInputStream(file), stream.getOutputStream());
			      }
			    }
			    /*}
			      catch(Exception e1)
			      {
			      //从文件服务器下载文件
			      file = Platform.fsDownload(fileName);
			      if(file == null)
			      {
			      log.error("mstreamLoad fsDownload error.");
			      }
			      }*/
			  }
			  catch(Exception e2)
			  {
			    log.error("{}","mstreamLoad copy error.");
			  }
			}
			catch (Exception e)
			{
			  log.error("{}","mstreamLoad error.", e);
			}
		}

        /**
        *   source:sysmod.@0204.script
        */
		public static java.io.File fsDownload(String fileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **从文件服务器下载文件
			  **参数为文件存储的路径
			  **/
			byte[] buffer = null;
			java.io.File file = null;
			Object object = MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsDownload",fileName);
			if(MdaUtils.isEmpty(object)|| object == null)
			{
			  log.info("{}","fsDownload from fileserver is null.");
			  //file = null;
			}
			else
			{
			  log.info("{}","fsDownload from fileserver is notnull.");
			  buffer = (byte[])object;
			  file = new java.io.File(fileName);
			  try
			  {
			    if(!file.exists())
			    {
			      int lastIndex = fileName.lastIndexOf("/");
			      if( lastIndex > 0 )
			      {
			        String path =  fileName.substring(0,lastIndex);
			        java.io.File dir = new java.io.File(path);
			        if(!dir.exists())
			        {
			          dir.mkdirs();
			        }
			      }
			      file.createNewFile();
			    }
			    java.io.FileOutputStream fos = new java.io.FileOutputStream(file);
			    try
			    {
			      fos.write(buffer);
			      fos.close();
			    }
			    catch (Exception e)
			    {
			      //e.printStackTrace();
			      log.error("{}","fsDownload writeOrClose error.");
			    }
			  }
			  catch (Exception e1)
			  {
			    //e1.printStackTrace();
			    log.error("{}","fsDownload error.");
			  }
			}
			return file;
		}

        /**
        *   source:sysmod.@0205.script
        */
		public static boolean mfileExists(String fileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.fileExists(fileName))
			{
			  log.info("{}","file local existed.");
			  return true;
			}
			else
			{
			  log.info("{}","file local unexisted,try get from fileserver.");
			  boolean flg = Platform.fsExists(fileName);

			  if(flg)
			  {
			    /*需判断为路径，还是文件，如是路径，则仅需创建即可，20180817添加判断*/
			    String[] str = fileName.split("\\.");
			    if(fileName.endsWith("/") || fileName.endsWith("\\") || fileName.endsWith("/") || fileName.endsWith("//") || (str.length < 2) )
			    {
			      //为路径，直接新加即可
			      MdaUtils.fileMkdirs(fileName);
			    }
			    else
			    {
			      //为文件，需从文件服务器下载文件
			      Platform.fsDownload(fileName);
			    }
			  }
			  return flg;
			}
		}

        /**
        *   source:sysmod.@0206.script
        */
		public static boolean fsExists(String fileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **判断文件服务器中是否存在文件
			  **/
			boolean flg = false;
			flg = (Boolean)MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsExists",fileName);
			log.info("{}","fileserver fsExists status:"+flg);
			return flg;
		}

        /**
        *   source:sysmod.@0207.script
        */
		public static boolean mfileDelete(String fileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.fileDelete(fileName))
			{
			  //从文件服务器上删除文件
			  return Platform.fsDelete(fileName);
			}
			return false;
		}

        /**
        *   source:sysmod.@0208.script
        */
		public static boolean fsDelete(String fileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **从文件服务器中删除文件
			  **待完善
			  **/
			boolean flg = false;
			flg = (Boolean)MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsDelete",fileName);
			log.info("{}","fileserver fsDelete status:"+flg);
			return flg;
		}

        /**
        *   source:sysmod.@0209.script
        */
		public static boolean mfileMove(String sourcefileNameOrPath, String targetFileOrPathName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean fsRtn = Platform.fsMove(sourcefileNameOrPath,targetFileOrPathName);
			if(fsRtn)
			{
			  if(MdaUtils.fileExists(targetFileOrPathName))
			    return MdaUtils.fileMove(sourcefileNameOrPath,targetFileOrPathName+".bak");
			  else
			    return MdaUtils.fileMove(sourcefileNameOrPath,targetFileOrPathName);
			}
			else
			{
			  return false;
			}
		}

        /**
        *   source:sysmod.@0210.script
        */
		public static boolean fsMove(String sourcefileNameOrPath, String targetFileOrPathName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **移动文件服务器中文件
			  **待完善
			  **/
			boolean flg  = false;
			flg = (Boolean)MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsMove",sourcefileNameOrPath,targetFileOrPathName);
			log.info("{}","fileserver fsMove status:"+flg);
			return flg;
		}

        /**
        *   source:sysmod.@0211.script
        */
		public static boolean mfileCopy(String sourceFileName, String targetFileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean rtn = MdaUtils.fileCopy(sourceFileName,targetFileName);
			if(rtn)
			{
			  return Platform.fsCopy(sourceFileName,targetFileName);
			}
			else
			  return false;
		}

        /**
        *   source:sysmod.@0212.script
        */
		public static boolean fsCopy(String sourceFileName, String targetFileName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **复制文件服务器中文件
			  **待完善
			  **/
			boolean flg = false;
			flg = (Boolean)MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsCopy",sourceFileName,targetFileName);
			log.info("{}","fileserver fsCopy status:"+flg);
			return flg;
		}

        /**
        *   source:sysmod.@0213.script
        */
		public static boolean mfileMkdirs(String filePath)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.fileMkdirs(filePath))
			{
			  log.info("{}","local mkdir success.");
			  return Platform.fsMkdirs(filePath);
			}
			else
			  return false;
		}

        /**
        *   source:sysmod.@0214.script
        */
		public static boolean fsMkdirs(String filePath)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **在文件服务器中创建文件夹
			  **/
			boolean flg  = false;
			flg = (Boolean)MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsMkdirs",filePath);
			log.info("{}","fileserver mkdir status:"+flg);
			return flg;
		}

        /**
        *   source:sysmod.@0215.script
        */
		public static List<String> mlistFiles(String path, String... extensions)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<String> lst = new ArrayList<String>();
			lst = MdaUtils.listFiles(path,extensions);
			if(lst.size()<=0)
			{
			  log.info("{}","local listfiles failed,try get from fileserver.");
			  String str = "";
			  if(!MdaUtils.isEmpty(extensions) && extensions != null && extensions.length > 0)
			  {
			    for(int i = 0;i < extensions.length - 1; i++){
			      str += extensions[i]+",";
			  }
			  str += extensions[extensions.length - 1];
			}
			log.info("{}","args message:"+str);
			lst =  Platform.fsListFiles(path,str);
			}
			return lst;
		}

        /**
        *   source:sysmod.@0216.script
        */
		public static List<String> fsListFiles(String path, String filtyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **列出文件服务器中指定路径下，指定文件类型的文件列表
			  **/
			List<String> lst = new ArrayList<String>();
			Object object  = MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsListFiles",path,filtyp);
			if(MdaUtils.isEmpty(object) || object == null)
			{
			  log.info("{}","get from fileserver listfiles null");
			  //lst = null;
			}
			else
			{
			  log.info("{}","get from fileserver listfiles notnull");
			  lst = (List<String>)object;
			  for(String fileName:lst)
			  {
			    Platform.fsDownload(fileName);
			  }
			}
			return lst;
		}

        /**
        *   source:sysmod.@0217.script
        */
		public static List<String> mlistDirectories(String path)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<String> lst = new ArrayList<String>();
			lst = MdaUtils.listFiles(path);
			if(lst.size()<=0)
			  lst = Platform.fsListDirs(path);
			return lst;
		}

        /**
        *   source:sysmod.@0218.script
        */
		public static List<String> fsListDirs(String path)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **列出文件服务器中指定路径文件夹列表
			  **/
			List<String> lst = new ArrayList<String>();
			Object object  = MdaUtils.invoke("cn.com.brilliance.psbc.client.imp.FileImp","fsListDirs",path);
			if(MdaUtils.isEmpty(object) || object == null)
			{
			  log.info("{}","get from fileserver listdirs null");
			  //lst = null;
			}
			else
			{
			  log.info("{}","get from fileserver listdirs notnull");
			  lst = (List<String>)object;
			}
			return lst;
		}

        /**
        *   source:sysmod.@0222.script
        */
		public static boolean isCurrentWritable(String dbName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return true;
		}

        /**
        *   source:sysmod.@0223.script
        */
		public static boolean setQzjStatus(Map<String,Object> arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean currentWritable = Platform.isCurrentWritable("eibs");
			if(currentWritable || (!MdaUtils.isEmpty(arguments.get("sendHost"))))
			{
			  int errcode = ctx.getErrorCode();
			  Fipsta fipsta = new Fipsta(Platform.getModuleRoot());
			  String chncod = (String)arguments.get("chncod");
			  String manaip = (String)arguments.get("manaip");
			  Boolean status = (Boolean)arguments.get("status");
			  Platform.mdbRead(fipsta,new Argument("chncod",chncod).and("manaip",manaip).and("status",NE,status.toString()));
			  if(!MdaUtils.isEmpty(fipsta.getEibsInr()))
			  {
			    Platform.mdbBegin();
			    fipsta.setEibsStatus(status.toString());
			    fipsta.setEibsChgdat(MdaUtils.today());
			    Platform.mdbUpdate(fipsta);
			    if(ctx.getErrorCode()!=NO_ERROR)
			    {
			      log.debug("{}","setQzjStatus fipsta update errorcod....");
			      Platform.mdbRollback();
			    }
			    else
			    {
			      Platform.mdbCommit();
			      if(ctx.getErrorCode()!=NO_ERROR)
			      {
			        return true;
			      }
			    }
			  }
			  else
			  {
			    return true;
			  }
			}
			/*
			  else
			  {
			  return (boolean)Platform.invoke("cn.com.brilliance.psbc.service.remote.DualCores","setQzjStatusOnAnotherCore",arguments);
			  }
			  */
			return false;
		}

        /**
        *   source:sysmod.@0225.script
        */
		public static void mdbDisconnect()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String beginDB = (String)Platform.getStoredData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			if(beginDB==null)
			{
			  int errorCode = ctx.getErrorCode();
			  ctx.getDaoSession().dbDisconnect();
			  ctx.setErrorCode(errorCode);
			}
		}

        /**
        *   source:sysmod.@0227.script
        */
		public static void esdbFetchFields(Object hibernateImpl,IResult... result)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			((org.sss.module.hibernate.HibernateImpl)hibernateImpl).fetch(result);
		}

        /**
        *   source:sysmod.@0228.script
        */
		public static void esdbDisconnect(Object hibernateImpl)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			((org.sss.module.hibernate.HibernateImpl)hibernateImpl).disconnect();
		}

        /**
        *   source:sysmod.@0229.script
        */
		public static void esdbCloseCursor(Object hibernateImpl)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			((org.sss.module.hibernate.HibernateImpl)hibernateImpl).close();
			esdbDisconnect(hibernateImpl);
		}

        /**
        *   source:sysmod.@0230.script
        */
		public static Object esdbExecuteSQL(String db,String sql)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return esdbExecuteSQL(db,sql,new Object[0]);
		}

        /**
        *   source:sysmod.@0231.script
        */
		public static Object esdbExecuteSQL(String db,String sql,Object... args)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = new org.sss.module.hibernate.HibernateImpl(ctx);
			try
			{
			  hibernateImpl.getClass().getMethod("init").invoke(hibernateImpl);
			}
			catch(Exception e)
			{
			  log.error("{}",e.getMessage());
			}
			if(db==null)
			{
			  db = Platform.getDbFromSql(sql);
			}
			hibernateImpl.reconnect(db);
			hibernateImpl.execute(sql,args);
			return (Object)hibernateImpl;
		}

        /**
        *   source:sysmod.@0232.script
        */
		public static String getTableDB(String tableName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String tbl = "com.brilliance.eibs.etrade."+tableName.substring(0,1).toUpperCase()+tableName.substring(1);
			Object mapObj = getStoredData("DbMap");
			if(mapObj==null)
			{
			  String path = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"WEB-INF/classes");
			  mapObj = MdaUtils.invoke("com.brilliance.xml.DbMapping","getMap",path);
			  ctx.storeData("DbMap",mapObj);
			}
			Map<String,String> map = (Map<String,String>)mapObj;
			String db = map.get(tbl);
			if(db==null||db.contains(","))
			{
			  db=Platform.getDefaultDB();
			}
			log.trace("{}","getTableDB "+tableName+" "+db);
			return db;
		}

        /**
        *   source:sysmod.@0233.script
        */
		public static void esdbRead(String db,IModule module,Argument... arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = new org.sss.module.hibernate.HibernateImpl(ctx);
			try
			{
			  hibernateImpl.getClass().getMethod("init").invoke(hibernateImpl);
			}
			catch(Exception e)
			{
			  log.error("{}",e.getMessage());
			}
			if(db==null)
			{
			  db = getModuleDB(module);
			}
			hibernateImpl.reconnect(db);
			hibernateImpl.get(module, arguments);
			int err = ctx.getErrorCode();
			hibernateImpl.disconnect();
			ctx.setErrorCode(err);
		}

        /**
        *   source:sysmod.@0234.script
        */
		public static void esdbReadset(String db,IModuleList list,int maxSize,Argument... arguments)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = new org.sss.module.hibernate.HibernateImpl(ctx);
			try
			{
			  hibernateImpl.getClass().getMethod("init").invoke(hibernateImpl);
			}
			catch(Exception e)
			{
			  log.error("{}",e.getMessage());
			}
			if(db==null)
			{
			  db = Platform.getModuleListDB(list);
			}
			hibernateImpl.reconnect(db);
			hibernateImpl.find(list, maxSize, arguments);
			int err = ctx.getErrorCode();
			hibernateImpl.disconnect();
			ctx.setErrorCode(err);
		}

        /**
        *   source:sysmod.@0235.script
        */
		public static void delCharTerm(IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  **删除String字段中的字符串终止符,postgresql的varchar字段中不允许出现字符串终止符
			  **/
			java.lang.reflect.Field[] fields = module.getClass().getDeclaredFields();
			for(int i=0;i<fields.length;i++)
			{
			  try
			  {
			    Object obj = fields[i].get(module);
			    if(obj instanceof IDatafield)
			    {
			      IDatafield<String> idf =(IDatafield)obj;
			      Object value = idf.getValue();
			      if(value!=null && (value instanceof String) && ((String)value).contains("\0"))
			        idf.setValue(((String)value).replace("\0",""));
			    }
			  }
			  catch(Exception e)
			  {
			    continue;
			  }
			}
		}

        /**
        *   source:sysmod.@0236.script
        */
		public static void esdbReadset(String db,IModuleList list,int maxSize,String sql)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = new org.sss.module.hibernate.HibernateImpl(ctx);
			try
			{
			  hibernateImpl.getClass().getMethod("init").invoke(hibernateImpl);
			}
			catch(Exception e)
			{
			  log.error("{}",e.getMessage());
			}
			if(db==null)
			{
			  db = Platform.getModuleListDB(list);
			}
			hibernateImpl.reconnect(db);
			hibernateImpl.find(list, maxSize, sql);
			int err = ctx.getErrorCode();
			hibernateImpl.disconnect();
			ctx.setErrorCode(err);
		}

        /**
        *   source:sysmod.@0237.script
        */
		public static String esdbCounter(String db,String counterName,String pattern)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String rst = null;
			if(Platform.checkFlgWithBussiness(db))
			{
			  org.sss.module.hibernate.HibernateImpl hibernateImpl = new org.sss.module.hibernate.HibernateImpl(ctx);
			  try
			  {
			    hibernateImpl.getClass().getMethod("init").invoke(hibernateImpl);
			  }
			  catch(Exception e)
			  {
			    log.error("{}",e.getMessage());
			  }
			  if(db==null)
			  {
			    db = Platform.getTableDB(counterName);
			  }
			  hibernateImpl.reconnect(db);
			  int cnt = hibernateImpl.count(counterName);
			  rst = MdaUtils.format(cnt,pattern);
			  int err = ctx.getErrorCode();
			  hibernateImpl.disconnect();
			  ctx.setErrorCode(err);
			  //return rst;
			}
			else
			{
			  log.info("{}","当前中心数据库不可用.");
			  rst = Platform.csdbCounter(db,counterName,pattern);
			}
			return rst;
		}

        /**
        *   source:sysmod.@0238.script
        */
		public static String esdbCounter(String db,IModule module,String pattern)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return Platform.esdbCounter(db,MdaDriver.getModuleType(module),pattern);
		}

        /**
        *   source:sysmod.@0239.script
        */
		public static String esdbCounter(String db,IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return Platform.esdbCounter(db,MdaDriver.getModuleType(module),"00000000");
		}

        /**
        *   source:sysmod.@0240.script
        */
		public static String esdbCounter(String db,String counterName)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return Platform.esdbCounter(db,counterName,"00000000");
		}

        /**
        *   source:sysmod.@0241.script
        */
		public static String getCurrentDBName()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String dbName = null;
			try
			{
			  Object suppport = ctx.getSupport();
			  java.lang.reflect.Field field = Class.forName("org.sss.module.pojo.AbstractPOJOImpl").getDeclaredField("session");
			  field.setAccessible(true);
			  Object sessionEx = field.get((org.sss.module.pojo.AbstractPOJOImpl)suppport);
			  dbName = ((org.sss.module.hibernate.SessionEx)sessionEx).getName();
			}
			catch(Exception e)
			{
			  e.printStackTrace();
			}
			return dbName;
		}

        /**
        *   source:sysmod.@0242.script
        */
		public static String rightPadChs(String source,String charPad,int fullLength)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//如果字符串是空
			if(MdaUtils.isEmpty(source))
			{
			  String padStr = "";
			  for(int i = 0;i<fullLength;i++)
			    padStr += charPad;

			  return padStr;
			}
			else
			{
			  byte[] b=source.getBytes();
			  int length = fullLength - b.length;
			  log.debug("{}","有效内容长度:"+b.length);
			  if(length <= 0)
			    return source;
			  else
			  {
			    String padStr = "";
			    for(int i = 0;i<length;i++)
			      padStr += charPad;

			    return source + padStr;
			  }
			}
		}

        /**
        *   source:sysmod.@0243.script
        */
		public static boolean checkFlgWithBussiness(String bustyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = (String)Platform.getStoredData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			if(db == null)
			{
			  db = bustyp;
			}
			//根据业务类型（或默认数据库）和主机名，判断是否可执行该业务
			java.net.InetAddress addr = null;
			String hstnam = "";
			try
			{
			  addr = java.net.InetAddress.getLocalHost();
			  hstnam = addr.getHostName().toString();
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			}
			/*
			  * 获取该主机对应的可操作业务列表
			  */
			hstnam = hstnam.substring(0,1);//取主机名第一位，即可表示该主机属于哪个中心
			/*
			  Bnssta bnssta = new Bnssta(Platform.getModuleRoot());
			  //log.info("db:"+db+",hstnam:"+hstnam);
			  Platform.errorCode();
			  Platform.esdbRead(db,bnssta,new Argument<String>("bustyp",db),new Argument<String>("hstnam",hstnam),new Argument<String>("status","1"));
			  int err = Platform.errorCode();
			  //log.info("errocde:"+err);
			  //log.info("bnssta-inr:"+bnssta.getEibsInr());
			  if(!Platform.isEmpty(bnssta.getEibsInr()))
			  */
			Object obj = MdaUtils.invoke("cn.com.brilliance.psbc.service.TaskManager","getBnssta",db);
			if(obj!=null && (Boolean)obj)
			{
			  // log.info("true......");
			  return true;
			}
			else
			{
			  //log.info("false......");
			  String busnam = MdaUtils.getCodetableLabel("bnssta",db);//读取对应码表配置信息
			  ctx.setMessage(MdaUtils.getI18NString("sysmod","CT000268"),MdaUtils.getI18NString("sysmod","CT000269")+busnam+MdaUtils.getI18NString("sysmod","CT000270"));
			  return false;
			}
		}

        /**
        *   source:sysmod.@0246.script
        */
		public static String[] getBuslst()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(ctx==null)
			{
			  ctx = new org.sss.presentation.zk.ZkContext();
			  RuleUtils.ctx.set(ctx);
			}
			String[] rtns = new String[3];
			try
			{
			  java.net.InetAddress addr = java.net.InetAddress.getLocalHost();
			  rtns[0] = addr.getHostName().toString();
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			}
			String hstnamstr = rtns[0].substring(0,1);
			log.info("{}","hst.substring(0,1):"+hstnamstr);
			rtns[1] = getEnableBuslst(hstnamstr);
			rtns[2] = getDsiableBuslst(hstnamstr);
			if(rtns[1]==null)
			{
			  rtns[1]="";
			}
			if(rtns[2]==null)
			{
			  rtns[2]="";
			}
			return rtns;
		}

        /**
        *   source:sysmod.@0247.script
        */
		public static String getHostName()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String hstnam = "";
			try
			{
			  java.net.InetAddress addr = java.net.InetAddress.getLocalHost();
			  hstnam = addr.getHostName().toString();
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			}
			return hstnam;
		}

        /**
        *   source:sysmod.@0248.script
        */
		public static boolean csdbInsertOrUpdate(String db,List list)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Map<String,Object> map = new HashMap <String,Object> ();
			map.put("PCODE","csdbInsertOrUpdate");
			map.put("db",db);
			map.put("list",list);
			Map<String,Object> rspMap = (Map<String,Object>)MdaUtils.invoke("cn.com.brilliance.psbc.service.cluster.ClusterConfig","sendRequestToClusterCloud",map);
			log.debug("{}","csdbInsertOrUpdate rspMap:"+rspMap);
			String respcode = (String)rspMap.get("RESPCODE");
			if("000000".equals(respcode))
			{
			  return true;
			}
			else
			{
			  return false;
			}
		}

        /**
        *   source:sysmod.@0249.script
        */
		public static String csdbCounter(String db,String counterName,String pattern)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Map<String,Object> map = new HashMap <String,Object> ();
			map.put("PCODE","csdbCounter");
			map.put("db",db);
			map.put("counterName",counterName);
			map.put("pattern",pattern);
			Map<String,Object> rspMap = (Map<String,Object>)MdaUtils.invoke("cn.com.brilliance.psbc.service.cluster.ClusterConfig","sendRequestToClusterCloud",map);
			log.debug("{}","csdbInsertOrUpdate rspMap:"+rspMap);
			String respcode = (String)rspMap.get("RESPCODE");
			if("000000".equals(respcode))
			{
			  return (String)rspMap.get("COUNT");
			}
			else
			{
			  return null;
			}
		}

        /**
        *   source:sysmod.@0250.script
        */
		public static String getEnableBuslst(String hst)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String str = null;
			String sql = "SELECT busnam FROM bnssta WHERE status = '1' AND hstnam = '"+hst+"' ";
			Argument<String> busnam = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object impl = Platform.esdbExecuteSQL("eibs",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(impl,busnam);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnam.value;
			    }
			    else
			    {
			      str=str+","+busnam.value;
			    }
			  }
			  Platform.esdbCloseCursor(impl);
			}

			Argument<String> busnamSwd = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object implSwd = Platform.esdbExecuteSQL("swd",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(implSwd,busnamSwd);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnamSwd.value;
			    }
			    else
			    {
			      str=str+","+busnamSwd.value;
			    }
			  }
			  Platform.esdbCloseCursor(implSwd);
			}
			Argument<String> busnamFxd = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object implFxd = Platform.esdbExecuteSQL("fxd",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(implFxd,busnamFxd);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnamFxd.value;
			    }
			    else
			    {
			      str=str+","+busnamFxd.value;
			    }
			  }
			  Platform.esdbCloseCursor(implFxd);
			}
			Argument<String> busnamErd = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object implErd = Platform.esdbExecuteSQL("erd",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(implErd,busnamErd);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnamErd.value;
			    }
			    else
			    {
			      str=str+","+busnamErd.value;
			    }
			  }
			  Platform.esdbCloseCursor(implErd);
			}
			Argument<String> busnamRyd = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object implRyd = Platform.esdbExecuteSQL("ryd",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(implRyd,busnamRyd);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnamRyd.value;
			    }
			    else
			    {
			      str=str+","+busnamRyd.value;
			    }
			  }
			  Platform.esdbCloseCursor(implRyd);
			}
			return str;
		}

        /**
        *   source:sysmod.@0251.script
        */
		public static String getDsiableBuslst(String hst)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String str = null;
			String sql = "SELECT busnam FROM bnssta WHERE status = '1' AND hstnam != '"+hst+"' ";
			Argument<String> busnam = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object impl = Platform.esdbExecuteSQL("eibs",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(impl,busnam);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnam.value;
			    }
			    else
			    {
			      str=str+","+busnam.value;
			    }
			  }
			  Platform.esdbCloseCursor(impl);
			}

			Argument<String> busnamSwd = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object implSwd = Platform.esdbExecuteSQL("swd",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(implSwd,busnamSwd);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnamSwd.value;
			    }
			    else
			    {
			      str=str+","+busnamSwd.value;
			    }
			  }
			  Platform.esdbCloseCursor(implSwd);
			}
			Argument<String> busnamFxd = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object implFxd = Platform.esdbExecuteSQL("fxd",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(implFxd,busnamFxd);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnamFxd.value;
			    }
			    else
			    {
			      str=str+","+busnamFxd.value;
			    }
			  }
			  Platform.esdbCloseCursor(implFxd);
			}
			Argument<String> busnamErd = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object implErd = Platform.esdbExecuteSQL("erd",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(implErd,busnamErd);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnamErd.value;
			    }
			    else
			    {
			      str=str+","+busnamErd.value;
			    }
			  }
			  Platform.esdbCloseCursor(implErd);
			}
			Argument<String> busnamRyd = new Argument<String>("busnam");
			ctx.getErrorCode();
			Object implRyd = Platform.esdbExecuteSQL("ryd",sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  while(true)
			  {
			    Platform.esdbFetchFields(implRyd,busnamRyd);
			    if(ctx.getErrorCode() != NO_ERROR)
			      break;
			    if(str==null)
			    {
			      str=busnamRyd.value;
			    }
			    else
			    {
			      str=str+","+busnamRyd.value;
			    }
			  }
			  Platform.esdbCloseCursor(implRyd);
			}
			return str;
		}

        /**
        *   source:sysmod.@0252.script
        */
		public static boolean checkFlgWithBussiness2(String bustyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String db = (String)Platform.getStoredData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground());
			if(db == null)
			{
			  db = bustyp;
			}
			//根据业务类型（或默认数据库）和主机名，判断是否可执行该业务
			java.net.InetAddress addr = null;
			String hstnam = "";
			try
			{
			  addr = java.net.InetAddress.getLocalHost();
			  hstnam = addr.getHostName().toString();
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			}
			/*
			  * 获取该主机对应的可操作业务列表
			  */
			hstnam = hstnam.substring(0,1);//取主机名第一位，即可表示该主机属于哪个中心
			Bnssta bnssta = new Bnssta(Platform.getModuleRoot());
			ctx.getErrorCode();
			Platform.esdbRead(db,bnssta,new Argument<String>("bustyp",db),new Argument<String>("hstnam",hstnam),new Argument<String>("status","1"),new Argument<String>("flg","X"));
			int err = ctx.getErrorCode();
			if(!MdaUtils.isEmpty(bnssta.getEibsInr()))
			{
			  return true;
			}
			else
			{
			  String busnam = MdaUtils.getCodetableLabel("bnssta",db);//读取对应码表配置信息
			  ctx.setMessage(MdaUtils.getI18NString("sysmod","CT000301"),MdaUtils.getI18NString("sysmod","CT000302")+busnam+MdaUtils.getI18NString("sysmod","CT000303"));
			  return false;
			}
		}

        /**
        *   source:sysmod.@0253.script
        */
		public synchronized static String addThreadIdIfIsBackground()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isBackground())
			{
			  return String.valueOf(Thread.currentThread().getId());
			}
			else
			{
			  return "";
			}
		}

        /**
        *   source:sysmod.@0254.script
        */
		public static void esdbReadset(String db,IModuleList list,int maxSize,String whereClause,Object... datas)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = new org.sss.module.hibernate.HibernateImpl(ctx);
			try
			{
			  hibernateImpl.getClass().getMethod("init").invoke(hibernateImpl);
			}
			catch(Exception e)
			{
			  log.error("{}",e.getMessage());
			}
			if(db==null)
			{
			  db = Platform.getModuleListDB(list);
			}
			hibernateImpl.reconnect(db);
			hibernateImpl.find(list, maxSize, whereClause, datas);
			int err = ctx.getErrorCode();
			hibernateImpl.disconnect();
			ctx.setErrorCode(err);
		}

        /**
        *   source:sysmod.@0257.script
        */
		public static void smdbBegin(String db)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.mdbConnect(db);
			ctx.getDaoSession().dbBegin();
			ctx.storeData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground(),db);
		}

        /**
        *   source:sysmod.@0258.script
        */
		public static void sessionsReconect(String db)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//更新数据库读写状态缓存
			Platform.updateBnsstaMap();
			try
			{
			  java.lang.reflect.Field field = Class.forName("org.sss.module.hibernate.HibernateUtils").getDeclaredField("sessions");
			  field.setAccessible(true);
			  Map sessions = (Map)field.get(null);
			  sessions.put(db,org.sss.module.hibernate.HibernateUtils.createSession(db));
			}
			catch(Exception e)
			{
			  log.error("{}",e.getMessage());
			}
		}

        /**
        *   source:sysmod.@0259.script
        */
		public static void updateBnsstaMap()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//获取主机名
			java.net.InetAddress addr = null;
			String hstnam = " ";
			try
			{
			  hstnam=java.net.InetAddress.getLocalHost().getHostName();
			}
			catch (java.net.UnknownHostException e)
			{
			  e.printStackTrace();
			  log.error("{}",e.getMessage());
			}
			hstnam = hstnam.substring(0,1);
			Map<String,Boolean> bnsstaMap = new HashMap<String,Boolean>();
			String[] dbs = new String[]{"eibs","swd","fxd","ryd","erd"};
			for(String db:dbs)
			{
			  int err = ctx.getErrorCode();
			  Bnssta bnssta = new Bnssta(Platform.getModuleRoot());
			  Platform.esdbRead(db,bnssta,new Argument<String>("bustyp",db),new Argument<String>("hstnam",hstnam),new Argument<String>("status","1"));
			  err = ctx.getErrorCode();
			  if(err!=NO_ERROR && err!=NO_MORE_ROW)
			  {
			    log.error("{}","updateBnsstaMap read "+db+" error:"+err);
			    Object obj = MdaUtils.invoke("cn.com.brilliance.psbc.service.TaskManager","getBnssta",db);
			    if(obj!=null )
			    {
			      bnsstaMap.put(db,(Boolean)obj);
			    }
			  }
			  else
			  {
			    if(MdaUtils.isEmpty(bnssta.getEibsInr()))
			    {
			      bnsstaMap.put(db,false);
			    }
			    else
			    {
			      bnsstaMap.put(db,true);
			    }
			  }
			}
			MdaUtils.invoke("cn.com.brilliance.psbc.service.TaskManager","setBnsstaMap",bnsstaMap);
		}

        /**
        *   source:sysmod.@0260.script
        */
		public static Object muThdbBegin(String db)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(Platform.checkFlgWithBussiness(db))
			{
			  org.sss.module.hibernate.HibernateImpl hibernateImpl = new org.sss.module.hibernate.HibernateImpl(ctx);
			  try
			  {
			    hibernateImpl.getClass().getMethod("init").invoke(hibernateImpl);
			  }
			  catch(Exception e)
			  {
			    log.error("{}",e.getMessage());
			  }
			  hibernateImpl.reconnect(db);
			  hibernateImpl.begin();
			  ctx.storeData("BeginDB."+Platform.getModuleRoot()+Platform.addThreadIdIfIsBackground(),db);
			  return hibernateImpl;
			}
			else
			{
			  log.info("{}","当前中心数据库不可用.");
			  MdaUtils.exitRule();
				return false;
			}
		}

        /**
        *   source:sysmod.@0261.script
        */
		public static void muThdbCommit(Object suport)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = (org.sss.module.hibernate.HibernateImpl)suport;
			ctx.restoreData("BeginDB." + getModuleRoot() + addThreadIdIfIsBackground());
			hibernateImpl.commit();
			int errorCode = ctx.getErrorCode();
			hibernateImpl.disconnect();
			ctx.setErrorCode(errorCode);
		}

        /**
        *   source:sysmod.@0262.script
        */
		public static void muThdbRollback(Object suport)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = (org.sss.module.hibernate.HibernateImpl)suport;
			ctx.restoreData("BeginDB." + getModuleRoot() + addThreadIdIfIsBackground());
			hibernateImpl.rollback();
			int errorCode = ctx.getErrorCode();
			hibernateImpl.disconnect();
			ctx.setErrorCode(errorCode);
		}

        /**
        *   source:sysmod.@0263.script
        */
		public static void muThsdbInsert(Object suport,IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = (org.sss.module.hibernate.HibernateImpl)suport;
			Platform.delCharTerm(module);
			IDatafield<String> inr = (IDatafield)MdaDriver.getDatafield(module,"inr");
			inr.setValue(Platform.muThdbCounter(hibernateImpl,module));
			hibernateImpl.save(module);
		}

        /**
        *   source:sysmod.@0264.script
        */
		public static void muThdbUpdate(Object suport,IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = (org.sss.module.hibernate.HibernateImpl)suport;
			Platform.delCharTerm(module);
			hibernateImpl.update(module);
		}

        /**
        *   source:sysmod.@0265.script
        */
		public static String muThdbCounter(Object suport,IModule module)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			org.sss.module.hibernate.HibernateImpl hibernateImpl = (org.sss.module.hibernate.HibernateImpl)suport;
			String counterName = MdaDriver.getModuleType(module);
			int cnt = hibernateImpl.count(counterName);
			return MdaUtils.format(cnt,"00000000");
		}

        /**
        *   source:sysmod.@0267.script
        */
		public static void transAndCheckUetr(IDatafield df)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 20190422新加，用于判断uetr字段
			  * uetr的自动大写转小写，以及格式检查
			  */
			if(MdaUtils.isEmpty(df))
			{
			  return;
			}
			String ref = (String)df.getValue();
			if(!ref.matches("[0-9a-zA-Z -]*"))
			{
			  ctx.setFieldError(df,MdaUtils.getI18NString("sysmod","CT000305"));
			}
			else
			{
			  ref = ref.toLowerCase();
			  df.setValue(ref);
			  
			}
		}

        /**
        *   source:sysmod.@0281.script
        */
		public static String getLastMonth(Date date)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int year = MdaUtils.parseInt(MdaUtils.format(date,"yyyy"));
			int month = MdaUtils.parseInt(MdaUtils.format(date,"MM"));

			if(month == 1)
			{
			  month = 12;
			  year = year - 1;
			}
			else
			{
			  month = month - 1;
			}
			return year + String.format("%02d", month);
		}

        /**
        *   source:sysmod.@0282.script
        */
		public static boolean isValidDate(String date, String pattern)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  Date d = MdaUtils.parseDate(date,pattern);
			  if(d == null)
			  {
			    return false;
			  }
			}
			catch(Exception e)
			{
			  return false;
			}
			return true;
		}

        /**
        *   source:sysmod.@0283.script
        */
		public static Date getMonthFirstDate(String month)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  String date = month + "01";
			  return Platform.formatDateTime(MdaUtils.parseDate(date,"yyyyMMdd"),"000000");
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			  return null;
			}
		}

        /**
        *   source:sysmod.@0284.script
        */
		public static Date getNextMonthFirstDate(String month)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  Date date = MdaUtils.parseDate(month,"yyyyMM");
			  int year = MdaUtils.parseInt(MdaUtils.format(date,"yyyy"));
			  int mon = MdaUtils.parseInt(MdaUtils.format(date,"MM"));
			  if(mon == 12)
			  {
			    mon = 1;
			    year = year + 1;
			  }
			  else
			  {
			    mon = mon + 1;
			  }
			  return Platform.getMonthFirstDate(year + String.format("%02d", mon));
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			  return null;
			}
		}

        /**
        *   source:sysmod.@0287.script
        */
		public static String getDefaultRoleInr()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return "F9990999";
		}

        /**
        *   source:sysmod.@0289.script
        */
		public static Date getMonthLastDate(String month)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Date firstDate = MdaUtils.parseDate(month + "01","yyyyMMdd");
			int year = MdaUtils.parseInt(MdaUtils.format(firstDate,"yyyy"));
			int m = MdaUtils.parseInt(MdaUtils.format(firstDate,"MM"));
			if(m == 12)
			{
			  year = year + 1;
			  m = 1;
			}
			else
			{
			  m = m + 1;
			}
			Date nextMonthFirstDate = MdaUtils.parseDate(year + String.format("%02d", m) + "01","yyyyMMdd");
			Calendar c = Calendar.getInstance();
			c.setTime(nextMonthFirstDate);
			c.add(Calendar.DATE,-1);
			java.text.SimpleDateFormat formatter = new java.text.SimpleDateFormat("yyyy-MM-dd");
			String df = formatter.format(c.getTime());
			return MdaUtils.parseDate(df,"yyyy-MM-dd");
		}

        /**
        *   source:sysmod.@0291.script
        */
		public static void convertString2IStream(String str,IStream is,String encoding)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  is.getOutputStream().write(str.getBytes(encoding));
			  is.getOutputStream().flush();
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			}
		}

        /**
        *   source:sysmod.@0292.script
        */
		public static String convertIStream2String(IStream is, String encoding)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  return org.apache.commons.io.IOUtils.toString(is.getInputStream(),encoding);
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			}
			return null;
		}

        /**
        *   source:sysmod.@0293.script
        */
		public static Date getBopDateNow()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 获取申报当前日期
			  - 无
			  @ Date 申报当前日期
			  */
			//是取当前日期还是会计日期?
			//return Platform.today();
			return MdaUtils.parseDate(Platform.getAccountDate(),"yyyyMMdd");
		}

        /**
        *   source:sysmod.@0294.script
        */
		public static String getBopEncoding()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			return "gb18030";
		}

        /**
        *   source:sysmod.@0295.script
        */
		public static String changeEncoding(byte[] buffer, String encoding)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  return new String(buffer,encoding);
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			  return null;
			}
		}

}