package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.bo.Qre;
import com.ceb.gjjs.mda.bo.Qrd;
import com.ceb.gjjs.mda.bo.Stb;
import com.ceb.gjjs.mda.bo.Frm;
import com.ceb.gjjs.mda.bo.Smh;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.bo.Rof;
import com.ceb.gjjs.mda.bo.Wtd;
import com.ceb.gjjs.mda.bo.Mtm;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 查询查复公共处理模型
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Qrtmod extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Qrtmod.class);

        //报文一对话序号
        private String sesnum1;

        //报文二对话序号
        private String sesnum2;

        //报文一发送序号
        private String seqnum1;

        //报文二发送序号
        private String seqnum2;



	    @BDGetter
		private Qrd qrd;

	    @BDGetter
		private Wtd wtd;

	    @BDGetter
		private Rof rof;

		@BDGetter
		private ModuleList<Rof> roflst;

	    @BDGetter
		private Stb stb;

		@BDGetter
		private ModuleList<Stb> stblst;

	    @BDGetter
		private Mtm mtm;

		@BDGetter
		private ModuleList<Mtm> mtmlst;

	    @BDGetter
		private Smh smh;

		@BDGetter
		private ModuleList<Wtd> wtdlst;

	    @BDGetter
		private Qre qre;

	    @BDGetter
		private Frm frm;

	    @BDGetter
		private Rof roftmp;


		public Qrtmod()
        {
            super();
            setArgument();
        }

        public Qrtmod(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }




        /**
        *   source:qrtmod.@0000.script
        */
        public List<String> getKeyListInMsgBlock(String txt)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	从文本中提取要素列表
			  -	txt 待提取的文本
			  @ 从文本中提取出来的要素列表
			  */
			if(MdaUtils.isEmpty(txt))
			  return null;

			txt = txt.replaceAll("\r\n","\n");
			txt = txt.replaceAll("\n","\r\n");
			log.info("{}","mtm-txt:"+txt);

			List<String> keyList = new ArrayList<String>();
			String regex = "\\{#.+?#\\}";//要素以{#XXX#}形式存在
			///通过匹配器（Matcher）逐个匹配出要素，并添加到要素列表中
			Matcher keyMatcher = Pattern.compile(regex).matcher(txt);
			while(keyMatcher.find())
			{
			  keyList.add(keyMatcher.group());
			}
			return keyList;
		}
        /**
        *   source:qrtmod.@0001.script
        */
        public List<CodetableItem> setKeyComboboxList(String typ,String mtmtyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	生成要素下拉选项列表（用于拼组报文模版）
			  -	typ 		报文类型
			  - mtmtyp	模版类型（退改查）
			  @ ctiList（List<CodetableItem>） 要素下拉选项列表
			  */
			List<CodetableItem> ctiList = new ArrayList<CodetableItem>();
			if(MdaUtils.isEmpty(typ))
			{
			  Platform.mdbReadset(this.getMtmlst(),new Argument<Object>("ordnum",ASC));
			}
			else
			{
			  Argument<String> arg = new Argument("typ",EQ,typ);
			  if(!MdaUtils.isEmpty(mtmtyp))
			  {
			    arg = arg.and("mtmtyp",EQ,mtmtyp);
			  }
			  Platform.mdbReadset(this.getMtmlst(),arg,new Argument<Object>("ordnum",ASC));
			}
			for(int i=0;i<this.getMtmlst().fullSize();i++)
			{
			  CodetableItem cti = new CodetableItem(this.getMtmlst().getElement(i).getNam(),
			    this.getMtmlst().getElement(i).getInr());
			  ctiList.add(cti);
			}
			return ctiList;
		}
        /**
        *   source:qrtmod.@0002.script
        */
        public String combinMsg(String othbic,String msgtyp,String textBlock)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	根据文首和正文信息组装出完成的报文文本
			  - othbic 对手银行BIC
			  - msgtyp 报文类型
			  - textBlock 报文正文文本
			  @ msg（String） 组装完成的报文文本
			  */
			//20190328新加
			//if(textBlock.indexOf("\\r")<0 && textBlock.indexOf("\\n")>=0)
			//20190819优化
			if(MdaUtils.isEmpty(textBlock))
			  return null;

			textBlock = textBlock.replaceAll("\r\n","\n");
			textBlock = textBlock.replaceAll("\n","\r\n");
			log.info("{}","check-msg:"+textBlock);

			String basicHeader = this.basicheaderPackage("01");
			String appHeader = this.appheaderPackage(msgtyp,othbic,"N","","");
			String msgHeader = "{1:" + basicHeader + "}{2:" + appHeader + "}";
			String msg = msgHeader + "{4:\r\n";
			msg += textBlock + "\r\n-}";
			return msg;
		}
        /**
        *   source:qrtmod.@0003.script
        */
        public String basicheaderPackage(String b1c)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 报文基本文首信息组装测试程序（发报）
			  @	b1c	应用程序协议数据单元标识	常用选择 01，21，03，05
			  -	返回组装完成的报文基本文首字符串 basichead
			  */
			String basichead = "";
			//组装基本文首
			//应用程序标识符
			basichead += "F";
			//应用程序协议数据单元标识
			basichead += b1c;//两位数字
			//逻辑终端地址
			//String adr = "PSBCCNBJAXXX0000000000";
			//20160726修改
			String adr = ctx.absGet(Sysmod.class).getPtyBic();
			log.debug("{}","bic:"+adr);
			adr = adr.substring(0,8)+"A"+adr.substring(8).trim()+"0000000000";
			basichead += adr;
			//对话序号0001-9999循环使用
			/*int sesnum = Platform.mdbCounter("sesnum");
			  sesnum = sesnum%10000;
			  if(sesnum == 0)sesnum++;
			  basichead +=  Platform.format(sesnum,"0000");
			  //发送序号000001-999999循环使用
			  int seqnum = Platform.mdbCounter("seqnum");
			  seqnum = seqnum%1000000;
			  if(seqnum == 0)seqnum++;
			  basichead += Platform.format(seqnum,"000000");*/
			return basichead;
		}
        /**
        *   source:qrtmod.@0004.script
        */
        public String appheaderPackage(String a2c,String a2d,String a2e,String a2f,String a2g)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	组装报文应用文首
			  -	a2c	报文类别
			  -	a2d	接收地址（收报行BIC）
			  -	a2e	电报优先级	（S，U，N）
			  -	a2f	传送监控	（1，2，3）
			  -	a2g	失效时限	（3位数字5的倍数，a2e时为020）
			  @	返回组装成功的报文应用文首字符串 apphead
			  */
			String apphead = "";
			//输入输出标识符
			apphead += "I";
			//报文类别
			apphead += a2c;
			//接收地址
			a2d = this.transfromBICtoLTA(a2d);
			apphead += a2d;
			//电报优先级
			apphead += a2e;
			//传送监控
			apphead += a2f;
			//失效时限
			apphead += a2g;
			return apphead;
		}
        /**
        *   source:qrtmod.@0005.script
        */
        public List<String> getTagList(String msgtyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	获取指定类型的swift报文中的栏位列表
			  - swift报文类型
			  @ tagList（List<String>） 指定报文的栏位列表
			  */
			if(msgtyp == null || "".equals(msgtyp))
			  return null;
			List<String> tagList = new ArrayList<String>();
			///组装查询条件（消息类型已 MT XXX的形式）
			if (!msgtyp.startsWith("MT"))
			  msgtyp = "MT " + msgtyp;
			String sql = "SELECT tag FROM mfd WHERE mty=? ORDER BY tno ASC";
			Argument<String> tag = new Argument<String>("tag");
			Platform.mdbExecuteSQL(sql,msgtyp);
			while(true)
			{
			  Platform.mdbFetchFields(tag);
			  if(ctx.getErrorCode() == NO_ERROR)
			  {
			    tagList.add(tag.value);
			  }
			  else
			    break;
			}
			Platform.mdbCloseCursor();
			return tagList;
		}
        /**
        *   source:qrtmod.@0006.script
        */
        public IStream transfromStringToStream(IStream is,String str)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	将字符串转化为输出流
			  -	is 用于接收数据流的IStream对象
			  -	str 需要转化的源字符串
			  @	is 转化得到的数据流，如转化失败或者源字符串为空，返回null
			  */
			if(MdaUtils.isEmpty(str))
			{
			  return null;
			}
			byte[] data = str.getBytes();
			try
			{
			  is.getOutputStream().write(data);
			  is.getOutputStream().flush();
			  return is;
			}
			catch(Exception e)
			{
			  return null;
			}
		}
        /**
        *   source:qrtmod.@0007.script
        */
        public String transfromBICtoLTA(String bic)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	将BIC代码根据规则生成逻辑终端地址代码
			  - bic 源BIC代码
			  @ lta 转化生成的逻辑终端地址代码
			  */
			if(MdaUtils.isEmpty(bic) || bic.length() < 8)
			{
			  return null;
			}
			String lta = "";//LOGICAL TERMINAL ADDRESS
			String headBIC = bic.substring(0,8);
			lta += headBIC;
			lta += "X";//逻辑终端代码，n99类报文要求较高必须用"X"
			if(bic.length() == 11)
			{
			  String tailBIC = bic.substring(8,11);
			  lta += tailBIC;
			}
			else
			{
			  lta += "XXX";
			}
			return lta;
		}
        /**
        *   source:qrtmod.@0008.script
        */
        public void createMessageSmhInfo(IStream is)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getSmh());
			this.getSmh().setInr( Platform.sdbCounter("smh"));
			this.getSmh().setCrtfrm( ctx.getTransName().substring(0,6));
			this.getSmh().setDattim( MdaUtils.today());
		}
        /**
        *   source:qrtmod.@0009.script
        */
        public String transfromStreamToString(IStream is)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			StringBuffer sb = new StringBuffer();
			try
			{
			  java.io.InputStream ins = is.getInputStream();
			  byte[] buf = new byte[1024];
			  int len = -1;
			  while ((len = ins.read(buf)) != -1)
			  {
			    String str = new String(buf,0,len);
			    sb.append(str);
			  }
			}
			catch(Exception e)
			{
			  log.debug("{}","Stream提取文本异常：" + e);
			}
			return sb.toString();
		}
        /**
        *   source:qrtmod.@0010.script
        */
        public void createQreInfo(String casnum,String dsc,String sta)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getQre());
			this.getQre().setInr( Platform.sdbCounter("qre"));
			this.getQre().setCasnum( casnum);
			this.getQre().setFrmnam( Platform.sgetTransName());
			this.getQre().setUsr( MdaEnv.getLoginUser());
			this.getQre().setDattim( MdaUtils.today());
			this.getQre().setDsc( dsc);
			this.getQre().setSta( sta);
			Platform.mdbInsert(this.getQre());
			log.debug("{}","createQreInfo errorcode:"+ctx.getErrorCode());
		}
        /**
        *   source:qrtmod.@0011.script
        */
        public String subcombinMsg(String othbic,String msgtyp,String textBlock,String sesnum,String seqnum)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  *	根据文首和正文信息组装出完成的报文文本
			  - othbic 对手银行BIC
			  - msgtyp 报文类型
			  - textBlock 报文正文文本
			  @ msg（String） 组装完成的报文文本
			  */
			//20190813新加
			//if(textBlock.indexOf("\\r")<0 && textBlock.indexOf("\\n")>=0)
			//20190819优化
			if(MdaUtils.isEmpty(textBlock))
			  return null;

			textBlock = textBlock.replaceAll("\r\n","\n");
			textBlock = textBlock.replaceAll("\n","\r\n");
			log.info("{}","init-msg:"+textBlock);

			String basicHeader = this.basicheaderPackage("01");
			String appHeader = this.appheaderPackage(msgtyp,othbic,"N","","");
			String msgHeader = "{1:" + basicHeader + "}{2:" + appHeader + "}";
			String msg = msgHeader + "{4:\r\n";
			msg += textBlock + "\r\n-}";
			return msg;
		}
        /**
        *   source:qrtmod.@0012.script
        */
        public String basicheaderPackage(String b1c,String sesnum,String seqnum)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 报文基本文首信息组装测试程序（发报）
			  @	b1c	应用程序协议数据单元标识	常用选择 01，21，03，05
			  -	返回组装完成的报文基本文首字符串 basichead
			  */
			String basichead = "";
			//组装基本文首
			//应用程序标识符
			basichead += "F";
			//应用程序协议数据单元标识
			basichead += b1c;//两位数字
			//逻辑终端地址
			//String adr = "PSBCCNBJAXXX";
			//20160726修改
			String adr = ctx.absGet(Sysmod.class).getPtyBic();
			log.debug("{}","bic:"+adr);
			adr = adr.substring(0,8)+"A"+adr.substring(8).trim();
			basichead += adr;
			//对话序号0001-9999循环使用
			basichead += sesnum;
			//发送序号000001-999999循环使用
			basichead += seqnum;
			return basichead;
		}
        /**
        *   source:qrtmod.@0013.script
        */
        public String rtnMsg(String strm,String subtyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String strmsg = "\n" +strm;//由于分隔字符串是需要，故添加
			log.trace("{}","strmsg : "+strmsg);
			List<String[]> lst = this.msgTxtAnly(strmsg);
			String str = null;
			Map<String,String> map = this.generMap(lst);
			if("199".equals(subtyp))
			{
			  str = this.gener199Message(map);
			}
			else if("195".equals(subtyp))
			{
			  str = this.gener195Message(map);
			}
			else if("196".equals(subtyp))
			{
			  str = this.gener196Message(map);
			}
			else if("196".equals(subtyp))
			{
			  str = this.gener196Message(map);
			}
			else if("191".equals(subtyp))
			{
			  str = this.gener191Message(map);
			}
			else if("193".equals(subtyp))
			{
			  str = this.gener193Message(map);
			}
			else if("194".equals(subtyp))
			{
			  str = this.gener194Message(map);
			}
			return str;
		}
        /**
        *   source:qrtmod.@0014.script
        */
        public String gener191Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","savmap: " +savmap);
			Map<String,String> map = new HashMap<String,String>();
			String result = null;
			Object[] usr = new Object[3];
			usr[0] = "0191";//任务号
			String inr = Platform.sdbCounter("FMT191","000000");
			int dbInr = MdaUtils.parseInt(inr);
			dbInr = dbInr +1;
			usr[1] = String.format("%06d",dbInr);
			map.put("PCODE","100010");
			map.put("FMTTYP","191");
			String sndbic = (String)savmap.get("A16");//发起行行号
			map.put("SENDLT",sndbic.substring(0,8)+"A"+sndbic.substring(8));
			String bic = "8888XXXXAXXX";//接收行行号
			map.put("RECVLT",bic);//收报行行号
			String own = (String)savmap.get("SEQNO");
			map.put("SEQNO",own);//查询书号
			String oth = (String)savmap.get("OWNREF");
			map.put("ORI_SEQNO",oth);//原支付交易序号
			String s11msg = (String)savmap.get("11S");
			map.put("ORI_MTTYP",s11msg.substring(0,3));//原MT报文号
			String dat = s11msg.substring(3).trim();
			log.debug("{}","11S:"+s11msg+",mt:"+s11msg.substring(0,3)+",dat:"+dat);
			map.put("ORI_VAL_DATE",dat);//原委托日期
			map.put("CUR",(String)savmap.get("G51"));//币种
			map.put("CLEARING_BANK",(String)savmap.get("A16"));//撤销申请清算行
			String str = (String)savmap.get("F85");
			String regex = "\\{#.+?#\\}";
			if(!MdaUtils.isEmpty(str)&&!str.matches(regex))
			{
			  log.debug("{}","str..."+str);
			  map.put("POSTSCRIPT","/F85/"+str.trim());
			}
			usr[2] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","PackageFmt","191",usr);
			Boolean msg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!msg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000008"),MdaUtils.getI18NString("qrtmod","CT000009"));
			  return null;
			}
			//获取接口平台返回的内容
			Object data = MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+data);
			return (String)data;
		}
        /**
        *   source:qrtmod.@0015.script
        */
        public String gener193Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","savmap: " +savmap);
			Map<String,String> map = new HashMap<String,String>();
			String result = null;
			Object[] usr = new Object[3];
			usr[0] = "0193";//任务号
			String inr = Platform.sdbCounter("FMT193","000000");
			int dbInr = MdaUtils.parseInt(inr);
			dbInr = dbInr +1;
			usr[1] = String.format("%06d",dbInr);
			map.put("PCODE","100010");
			map.put("FMTTYP","193");
			String sndbic = (String)savmap.get("A34");//发起行行号
			map.put("SENDLT",sndbic.substring(0,8)+"A"+sndbic.substring(8));
			String bic = (String)savmap.get("A35");//接收行行号
			map.put("RECVLT",bic.substring(0,8)+"A"+bic.substring(8));//收报行行号
			String own = (String)savmap.get("SEQNO");
			map.put("SEQNO",own);//查询书号
			String oth = (String)savmap.get("OWNREF");
			map.put("ORI_SEQNO",oth);//原支付交易序号
			String s11msg = (String)savmap.get("11S");
			map.put("ORI_MTTYP",s11msg.substring(0,3));//原MT报文号
			String dat1 = s11msg.substring(3).trim();
			log.debug("{}","11S:"+s11msg+",mt:"+s11msg.substring(0,3)+",dat:"+dat1);

			map.put("ORI_VAL_DATE",dat1);//原委托日期
			String b00msg = (String)savmap.get("B00");
			//String dattim = Platform.format(b00msg,"yyyyMMdd");
			map.put("VAL_DATE",b00msg);//委托日期
			map.put("CUR",(String)savmap.get("G51"));//币种
			map.put("ORI_FMTTYP",(String)savmap.get("F31"));//原FMT号
			map.put("SEND_CLEARING_BANK",(String)savmap.get("A17"));//退汇申请清算行
			map.put("SEND_BANK",(String)savmap.get("A34"));//退汇申请行
			map.put("RECV_CLEARING_BANK",(String)savmap.get("A18"));//退汇应答清算行
			map.put("RECV_BANK",(String)savmap.get("A35"));//退汇应答行
			
			String str = (String)savmap.get("F85");
			String regex = "\\{#.+?#\\}";
			if(!MdaUtils.isEmpty(str)&&!str.matches(regex))
			{
			  log.debug("{}","str..."+str);
			  map.put("POSTSCRIPT","/F85/"+str.trim());
			}
			usr[2] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","PackageFmt","193",usr);
			Boolean msg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!msg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000016"),MdaUtils.getI18NString("qrtmod","CT000017"));
			  return null;
			}
			//获取接口平台返回的内容
			Object data = MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+data);
			return (String)data;
		}
        /**
        *   source:qrtmod.@0016.script
        */
        public String gener194Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","savmap: " +savmap);
			Map<String,String> map = new HashMap<String,String>();
			String result = null;
			Object[] usr = new Object[3];
			usr[0] = "0194";//任务号
			//usr[1] = (Object)Platform.sdbCounter("FMT194","000000");//报文序号
			String inr1 = Platform.sdbCounter("FMT194","000000");
			int dbInr1 = MdaUtils.parseInt(inr1);
			dbInr1 = dbInr1 +1;
			usr[1] = String.format("%06d",dbInr1);
			map.put("PCODE","100010");
			map.put("FMTTYP","194");
			String sndbic = (String)savmap.get("A35");
			map.put("SENDLT",sndbic.substring(0,8)+"A"+sndbic.substring(8));//发报行行号
			String bic = (String)savmap.get("A34");
			String ls = bic.substring(0,8)+"A"+bic.substring(8);
			map.put("RECVLT",ls);//收报行行号
			map.put("SEQNO",(String)savmap.get("SEQNO"));//退汇应答序号
			map.put("ORI_SEQNO",(String)savmap.get("OWNREF"));//原退汇申请序号,FMT193
			map.put("TH_RESPONSE",(String)savmap.get("76"));//退汇应答,0—同意退汇  1—不能退汇
			//String dattim = Platform.format((String)savmap.get("B00"),"yyyyMMdd");
			map.put("VAL_DATE",(String)savmap.get("B00").trim());//委托日期
			
			map.put("RECV_CLEARING_BANK",(String)savmap.get("A17"));//退汇申请清算行
			map.put("RECV_BANK",(String)savmap.get("A34"));//退汇申请行
			map.put("SEND_CLEARING_BANK",(String)savmap.get("A18"));//退汇应答清算行
			map.put("SEND_BANK",(String)savmap.get("A35"));//退汇应答行
			//map.put("POSTSCRIPT","/F85/"+(String)savmap.get("F85"));//附言
			String str = (String)savmap.get("F85");
			String regex = "\\{#.+?#\\}";
			if(!MdaUtils.isEmpty(str)&&!str.matches(regex))
			{
			  log.debug("{}","str..."+str);
			  map.put("POSTSCRIPT","/F85/"+str.trim());
			}
			map.put("CUR",(String)savmap.get("G51"));//币种
			//String dat1 = Platform.format((String)savmap.get("B93"),"yyyyMMdd");
			map.put("ORI_VAL_DATE",(String)savmap.get("B93").trim());//原退汇申请委托日期
			usr[2] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","PackageFmt","194",usr);
			Boolean msg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!msg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000036"),MdaUtils.getI18NString("qrtmod","CT000037"));
			  return null;
			}
			//获取接口平台返回的内容
			Object data = MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+data);
			return (String)data;
		}
        /**
        *   source:qrtmod.@0017.script
        */
        public String gener195Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","savmap: " +savmap);
			Map<String,String> map = new HashMap<String,String>();
			String result = null;
			Object[] usr = new Object[3];
			usr[0] = "0195";//任务号
			String inr = Platform.sdbCounter("FMT195","000000");
			int dbInr = MdaUtils.parseInt(inr);
			dbInr = dbInr +1;
			usr[1] = String.format("%06d",dbInr);
			map.put("PCODE","100010");
			map.put("FMTTYP","195");
			String sndbic = (String)savmap.get("A32");//发起行行号
			map.put("SENDLT",sndbic.substring(0,8)+"A"+sndbic.substring(8));
			String bic = (String)savmap.get("A33");//接收行行号
			map.put("RECVLT",bic.substring(0,8)+"A"+bic.substring(8));//收报行行号
			String own = (String)savmap.get("SEQNO");
			map.put("SEQNO",own);//查询书号
			String oth = (String)savmap.get("OWNREF");
			map.put("ORI_SEQNO",oth);//原支付交易序号
			String msg75 = (String)savmap.get("75");//查询内容
			map.put("QUERY_MSG",msg75);

			String dattim = (String)savmap.get("B05");
			map.put("VAL_DATE",dattim);//查询日期
			
			String sndclr = (String)savmap.get("A11");//发起行行号
			String rcvclr = (String)savmap.get("A12");//发起行行号
			map.put("SEND_CLEARING_BANK",sndclr);//查询清算行
			map.put("SEND_BANK",sndbic);//查询行行号
			map.put("RECV_CLEARING_BANK",rcvclr);//查复清算行
			map.put("RECV_BANK",bic);//查复行行号
			
			map.put("ORI_VAL_DATE",(String)savmap.get("B90"));//原委托日期,8位
			map.put("ORI_SEND_BANK",(String)savmap.get("A91"));//原发报行，11位
			map.put("ORI_RECV_BANK",(String)savmap.get("A92"));//原收报行，11位
			map.put("ORI_FMTTYP",(String)savmap.get("F31"));//原FMT类型，3位
			map.put("ORI_CA",(String)savmap.get("C90").replace(".",",").trim());//原货币符号，金额
			
			usr[2] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","PackageFmt","195",usr);
			Boolean msg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!msg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000056"),MdaUtils.getI18NString("qrtmod","CT000057"));
			  return null;
			}
			//获取接口平台返回的内容
			Object data = MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+data);
			return (String)data;
		}
        /**
        *   source:qrtmod.@0019.script
        */
        public String gener196Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","savmap: " +savmap);
			Map<String,String> map = new HashMap<String,String>();
			String result = null;
			Object[] usr = new Object[3];
			usr[0] = "0196";//任务号
			String inr = Platform.sdbCounter("FMT196","000000");
			int dbInr = MdaUtils.parseInt(inr);
			dbInr = dbInr +1;
			usr[1] = String.format("%06d",dbInr);
			map.put("PCODE","100010");
			map.put("FMTTYP","196");

			String sndbic = (String)savmap.get("A33");//发起行行号
			map.put("SENDLT",sndbic.substring(0,8)+"A"+sndbic.substring(8));
			String bic = (String)savmap.get("A32");//接收行行号
			map.put("RECVLT",bic.substring(0,8)+"A"+bic.substring(8));//收报行行号
			
			String own = (String)savmap.get("SEQNO");
			String oth = (String)savmap.get("OWNREF");
			map.put("SEQNO",own);//查复书号
			map.put("ORI_SEQNO",oth);//原查询书号
			map.put("QUERY_MSG",(String)savmap.get("76"));//查复内容
			
			map.put("VAL_DATE",(String)savmap.get("B06"));//查复日期
			map.put("SEND_CLEARING_BANK",(String)savmap.get("A11"));//发起清算行行号
			map.put("SEND_BANK",sndbic);//查复行行号
			map.put("RECV_CLEARING_BANK",(String)savmap.get("A12"));//接收清算行行号
			map.put("RECV_BANK",bic);//原查询行行号
			
			map.put("CUR",(String)savmap.get("G51"));//币种
			map.put("ORI_VAL_DATE",(String)savmap.get("B91"));//原委托日期
			usr[2] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","PackageFmt","196",usr);
			Boolean msg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!msg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000078"),MdaUtils.getI18NString("qrtmod","CT000079"));
			  return null;
			}
			//获取接口平台返回的内容
			Object data = MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+data);
			return (String)data;
		}
        /**
        *   source:qrtmod.@0020.script
        */
        public String gener199Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","savmap: " +savmap);
			Map<String,String> map = new HashMap<String,String>();
			String result = null;
			Object[] usr = new Object[14];
			usr[0] = "0199";//任务号
			String inr = Platform.sdbCounter("FMT199","000000");
			int dbInr = MdaUtils.parseInt(inr);
			dbInr = dbInr +1;
			usr[1] = String.format("%06d",dbInr);
			map.put("PCODE","100010");
			map.put("FMTTYP","199");

			String sndbic = (String)savmap.get("A41");//发起行行号
			if(sndbic.length()>4)
			{
			  map.put("SENDLT",sndbic.substring(0,8)+"A"+sndbic.substring(8));
			}
			else
			{
			  map.put("SENDLT",sndbic+"XXXXAXXX");
			}
			String bic = (String)savmap.get("A42");//接收行行号
			if(bic.length()>4)
			{
			  map.put("RECVLT",bic.substring(0,8)+"A"+bic.substring(8));//收报行行号
			}
			else
			{
			  map.put("RECVLT",bic+"XXXXAXXX");//收报行行号
			}
			String own = (String)savmap.get("SEQNO");
			map.put("SEQNO",own);//业务参考号
			
			String oth = (String)savmap.get("OWNREF");
			if(!MdaUtils.isEmpty(oth))
			{
			  map.put("OWNREF",oth);//原支付交易序号
			}
			String dattim = savmap.get("B00");
			map.put("VAL_DATE",dattim);//委托日期
			
			String sndclr = (String)savmap.get("A41");
			map.put("SEND_BIC",sndclr);//发起清算行
			map.put("SEND_BANK",sndbic);//发报行行号
			String rcvclr = (String)savmap.get("A42");
			map.put("RECV_BIC",rcvclr);//接收清算行
			if(rcvclr.length()>4)//非人行、结算银行才需送此域
			{
			  map.put("RECV_BANK",bic);//接收行行号
			}
			String inf = (String)savmap.get("F89");
			map.put("CONTENT","/F89/"+inf);//原查询内容
			usr[2] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","PackageFmt","199",usr);
			Boolean msg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!msg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000092"),MdaUtils.getI18NString("qrtmod","CT000093"));
			  return null;
			}
			//获取接口平台返回的内容
			Object data = MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+data);
			return (String)data;
		}
        /**
        *   source:qrtmod.@0021.script
        */
        public Map generMap(List<String[]> lst)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Map<String, String> infMap = new HashMap<String, String>();
			for(int i=0;i<lst.size();i++)
			{
			  String[] str = lst.get(i);
			  if(str[0].endsWith("20"))
			  {
			    if(!infMap.containsKey("SEQNO"))
			    {
			      if (str[1].length() > 16)
			        infMap.put("SEQNO",str[1].substring(0, 16).trim());
			      else
			        infMap.put("SEQNO",str[1].trim());
			    }
			  }
			  if(str[0].endsWith("21"))
			  {
			    if(!infMap.containsKey("OWNREF"))
			    {
			      if (str[1].length() > 16)
			        infMap.put("OWNREF",str[1].substring(0, 16).trim());
			      else
			        infMap.put("OWNREF",str[1].trim());
			    }
			  }
			  if(str[0].endsWith("11S"))
			  {
			    if(!infMap.containsKey("11S"))
			    {
			      infMap.put("11S",str[1].trim());
			    }
			  }
			  if(str[0].endsWith("75"))
			  {
			    if(!infMap.containsKey("75"))
			    {
			      infMap.put("75",str[1].trim());
			    }
			  }
			  if(str[0].endsWith("76"))
			  {
			    if(!infMap.containsKey("76"))
			    {
			      infMap.put("76",str[1].trim());
			    }
			  }
			  if(str[0].endsWith("11S"))
			  {
			    if(!infMap.containsKey("11S"))
			    {
			      infMap.put("11S",str[1].trim());
			    }
			  }
			  if(str[0].endsWith("77A"))
			  {
			    String str77msg = "\n" +str[1].trim();
			    log.trace("{}","77A--strmsg: "+str77msg);
			    List<String[]> lst2 = this.msgFmtAnly(str77msg);
			    for(int j=0;j<lst2.size();j++)
			    {
			      String[] str2 = lst2.get(j);
			      if(str2[0].endsWith("B05"))
			      {
			        if(!infMap.containsKey("B05")) infMap.put("B05", str2[1].trim());
			      }
			      if(str2[0].endsWith("B06"))
			      {
			        if(!infMap.containsKey("B06")) infMap.put("B06", str2[1].trim());
			      }
			      if(str2[0].endsWith("A11") )
			      {
			        if(!infMap.containsKey("A11")) infMap.put("A11", str2[1].trim());
			      }
			      if(str2[0].endsWith("A32") )
			      {
			        if(!infMap.containsKey("A32")) infMap.put("A32", str2[1].trim());
			      }
			      if(str2[0].endsWith("A12") )
			      {
			        if(!infMap.containsKey("A12")) infMap.put("A12", str2[1].trim());
			      }
			      if(str2[0].endsWith("A33") )
			      {
			        if(!infMap.containsKey("A33")) infMap.put("A33", str2[1].trim());
			      }
			      if(str2[0].endsWith("F89") )
			      {
			        if(!infMap.containsKey("F89")) infMap.put("F89", str2[1].trim());
			      }
			      //FMT194所需
			      if(str2[0].endsWith("B00") )
			      {
			        if(!infMap.containsKey("B00")) infMap.put("B00", str2[1].trim());
			      }
			      if(str2[0].endsWith("A17") )
			      {
			        if(!infMap.containsKey("A17")) infMap.put("A17", str2[1].trim());
			      }
			      if(str2[0].endsWith("A34") )
			      {
			        if(!infMap.containsKey("A34")) infMap.put("A34", str2[1].trim());
			      }
			      if(str2[0].endsWith("A18") )
			      {
			        if(!infMap.containsKey("A18")) infMap.put("A18", str2[1].trim());
			      }
			      if(str2[0].endsWith("A35") )
			      {
			        if(!infMap.containsKey("A35")) infMap.put("A35", str2[1].trim());
			      }
			      if(str2[0].endsWith("F85") )
			      {
			        if(!infMap.containsKey("F85")) infMap.put("F85", str2[1].trim());
			      }
			    }
			  }
			  if(str[0].endsWith("79"))
			  {
			    String strmsg = "\n" +str[1].trim();
			    log.trace("{}","79--strmsg: "+strmsg);
			    List<String[]> lst1 = this.msgFmtAnly(strmsg);
			    for(int j=0;j<lst1.size();j++)
			    {
			      String[] str1 = lst1.get(j);
			      if(str1[0].endsWith("A41"))
			      {
			        if(!infMap.containsKey("A41")) infMap.put("A41", str1[1].trim());
			      }
			      if(str1[0].endsWith("B00") )
			      {
			        if(!infMap.containsKey("B00")) infMap.put("B00", str1[1].trim());
			      }
			      if(str1[0].endsWith("A32") )
			      {
			        if(!infMap.containsKey("A32")) infMap.put("A32", str1[1].trim());
			      }
			      if(str1[0].endsWith("A42") )
			      {
			        if(!infMap.containsKey("A42")) infMap.put("A42", str1[1].trim());
			      }
			      if(str1[0].endsWith("A33") )
			      {
			        if(!infMap.containsKey("A33")) infMap.put("A33", str1[1].trim());
			      }
			      if(str1[0].endsWith("F89") )
			      {
			        if(!infMap.containsKey("F89")) infMap.put("F89", str1[1].trim());
			      }
			      //FMT195
			      if(str1[0].endsWith("B90") )
			      {
			        if(!infMap.containsKey("B90")) infMap.put("B90", str1[1].trim());
			      }
			      if(str1[0].endsWith("A91") )
			      {
			        if(!infMap.containsKey("A91")) infMap.put("A91", str1[1].trim());
			      }
			      if(str1[0].endsWith("A92") )
			      {
			        if(!infMap.containsKey("A92")) infMap.put("A92", str1[1].trim());
			      }
			      if(str1[0].endsWith("F31") )
			      {
			        if(!infMap.containsKey("F31")) infMap.put("F31", str1[1].trim());
			      }
			      if(str1[0].endsWith("C90") )
			      {
			        if(!infMap.containsKey("C90")) infMap.put("C90", str1[1].trim());
			      }
			      //FMT196
			      if(str1[0].endsWith("G51") )
			      {
			        if(!infMap.containsKey("G51")) infMap.put("G51", str1[1].trim());
			      }
			      if(str1[0].endsWith("B91") )
			      {
			        if(!infMap.containsKey("B91")) infMap.put("B91", str1[1].trim());
			      }
			      //fmt191
			      if(str1[0].endsWith("A16"))
			      {
			        if(!infMap.containsKey("A16")) infMap.put("A16", str1[1].trim());
			      }
			      if(str1[0].endsWith("F85"))
			      {
			        if(!infMap.containsKey("F85")) infMap.put("F85", str1[1].trim());
			      }
			      //FMT193
			      if(str1[0].endsWith("A17"))
			      {
			        if(!infMap.containsKey("A17")) infMap.put("A17", str1[1].trim());
			      }
			      if(str1[0].endsWith("A34"))
			      {
			        if(!infMap.containsKey("A34")) infMap.put("A34", str1[1].trim());
			      }
			      if(str1[0].endsWith("A18"))
			      {
			        if(!infMap.containsKey("A18")) infMap.put("A18", str1[1].trim());
			      }
			      if(str1[0].endsWith("A35"))
			      {
			        if(!infMap.containsKey("A35")) infMap.put("A35", str1[1].trim());
			      }
			      //FMT194
			      if(str1[0].endsWith("B93") )
			      {
			        if(!infMap.containsKey("B93")) infMap.put("B93", str1[1].trim());
			      }
			    }
			  }
			}
			return infMap;
		}
        /**
        *   source:qrtmod.@0022.script
        */
        public List<String[]> msgFmtAnly(String mt)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String[] tags =  mt.split("((\\r\\n)|(\\n\\r)|(\\r)|(\\n))/");
			List<String[]> list = new ArrayList<String[]>();
			for (String tv : tags)
			{
			  if (tv.trim().length() > 0)
			  {
			    int i = tv.indexOf('/');
			    if (i > 0)
			    {
			      String[] arr = new String[2];
			      arr[0] = tv.substring(0, i);
			      arr[1] = tv.substring(i + 1);
			      list.add(arr);
			    }
			  }
			}
			/*if (list.size() > 0)
			  {
			  String[] lstOne = list.get(list.size() - 1);
			  int i = lstOne[1].lastIndexOf("\\r\\n");
			  if (i < 0) {
			  i = lstOne[1].lastIndexOf("\\r");
			  }
			  if (i < 0) {
			  i = lstOne[1].lastIndexOf("\\n");
			  }
			  if (i > -1)
			  {
			  lstOne[1] = lstOne[1].substring(0, i);
			  list.set(list.size() - 1, lstOne);
			  }
			  }*/
			return list;
		}
        /**
        *   source:qrtmod.@0023.script
        */
        public List<String[]> msgTxtAnly(String mt)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String[] tags =  mt.split("((\\r\\n)|(\\n\\r)|(\\r)|(\\n)):");
			List<String[]> list = new ArrayList<String[]>();
			for (String tv : tags)
			{
			  if (tv.trim().length() > 0)
			  {
			    int i = tv.indexOf(':');
			    if (i > 0)
			    {
			      String[] arr = new String[2];
			      arr[0] = tv.substring(0, i);
			      arr[1] = tv.substring(i + 1);
			      list.add(arr);
			    }
			  }
			}
			/* if (list.size() > 0)
			  {
			  String[] lstOne = list.get(list.size() - 1);
			  int i = lstOne[1].lastIndexOf("\\r\\n");
			  if (i < 0) {
			  i = lstOne[1].lastIndexOf("\\r");
			  }
			  if (i < 0) {
			  i = lstOne[1].lastIndexOf("\\n");
			  }
			  if (i > -1)
			  {
			  lstOne[1] = lstOne[1].substring(0, i);
			  list.set(list.size() - 1, lstOne);
			  }
			  }*/
			return list;
		}
        /**
        *   source:qrtmod.@0025.script
        */
        public String rtnCipsMsg(String strm,String subtyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(strm)|| MdaUtils.isEmpty(subtyp))
			  return null;

			Map<String,String> map = (Map<String,String>)MdaUtils.invoke("com.brilliance.eibs.interfaceWork.json.JsonConvertor","stringToMap",strm,Map.class);
			log.debug("{}","map:"+map);
			String str = null;
			if("301".equals(subtyp))
			{
			  str = this.generCips301Message(map);
			}
			else if("302".equals(subtyp))
			{
			  str = this.generCips302Message(map);
			}
			else if("309".equals(subtyp))
			{
			  str = this.generCips309Message(map);
			}
			return str;
		}
        /**
        *   source:qrtmod.@0026.script
        */
        public String generCips309Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Map<String,Object> map = new HashMap<String,Object>();

			map.put("MsgId",savmap.get("MsgId"));//报文标识号
			map.put("HMsgRef",(String)savmap.get("Ref"));//报文参考号,取相关参考号
			map.put("HSender","PSBCCNBJXXX");//报文发起方
			map.put("HReceiver",(String)savmap.get("InstdPty"));//报文接收方
			map.put("HSendDate",(String)savmap.get("HSendDate"));//报文发起日期
			map.put("Tp","cips.309.001.01");//报文类型
			map.put("Ref",(String)savmap.get("Ref"));//相关参考号
			map.put("InstgPty","PSBCCNBJXXX");//发起直接参与者行号
			map.put("InstdPty",(String)savmap.get("InstdPty"));//接收直接参与者行号
			map.put("MsgCntt",(String)savmap.get("MsgCntt"));//信息内容
			Object[] obj = new Object[1];
			obj[0] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","cipsloginout","loginout",obj);
			Boolean rtnmsg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!rtnmsg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000096"),MdaUtils.getI18NString("qrtmod","CT000097"));
			  return null;
			}
			//获取接口平台返回的内容
			Object[] data = (Object[])MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+data[0]);
			return (String)data[0];
		}
        /**
        *   source:qrtmod.@0027.script
        */
        public String generCips302Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Map<String,Object> map = new HashMap<String,Object>();

			map.put("MsgId",(String)savmap.get("MsgId"));//报文标识号
			map.put("HMsgRef",(String)savmap.get("Case-OrgnlMsgId"));//报文参考号,取原查询业务报文标识号
			map.put("HSender","PSBCCNBJXXX");//报文发起方
			map.put("HReceiver",(String)savmap.get("Assgnr-MmbId"));//报文接收方
			map.put("HSendDate",(String)savmap.get("HSendDate"));//报文发起日期
			map.put("Tp","cips.302.001.02");//报文类型
			//Assgnr
			Map<String,Object> asemap = new HashMap<String,Object>();
			asemap.put("MmbId","PSBCCNBJXXX");//查复直接参与者行号
			if(!MdaUtils.isEmpty(savmap.get("Assgne-Id")))
			  asemap.put("Id",(String)savmap.get("Assgne-Id"));///查复间接参与者行号
			map.put("Assgnr",asemap);
			//Assgne
			Map<String,Object> asrmap = new HashMap<String,Object>();
			asrmap.put("MmbId",(String)savmap.get("Assgnr-MmbId"));//查询直接参与者行号
			if(!MdaUtils.isEmpty(savmap.get("Assgnr-Id")))
			  asrmap.put("Id",(String)savmap.get("Assgnr-Id"));//查询间接参与者行号
			map.put("Assgne",asrmap);
			String dattim = MdaUtils.format(MdaUtils.today(),"yyyy-MM-ddHH:mm:ss");
			map.put("CreDtTm",dattim.substring(0,10)+"T"+dattim.substring(10));//报文发送时间
			Map<String,Object> casmap = new HashMap<String,Object>();
			casmap.put("OrgnlMsgId",(String)savmap.get("Case-OrgnlMsgId"));//原查询业务报文标识号
			casmap.put("OrgnlMmbId",(String)savmap.get("Case-OrgnlMmbId"));//原业务发起直接参与者行号
			map.put("Case",casmap);

			map.put("DbtAuthstn","false");//DebitAuthorisation
			map.put("PlcAndNm","/Document/DbtAuthstnRspn/Case");//PlaceAndName
			
			String orgtyp = (String)savmap.get("OrgnlTp");
			if("111|112".contains(orgtyp))
			{
			  map.put("OrgnlTp","cips."+orgtyp+".001.02");//原报文类型
			}
			else
			  map.put("OrgnlTp","cips."+orgtyp+".001.01");//原报文类型
			//map.put("OrgnlTp",(String)savmap.get("OrgnlTp"));//原报文类型
			
			map.put("OrgnlMmbId",(String)savmap.get("OrgnlMmbId"));//原业务发起直接参与者行号
			map.put("OrgnlMsgId",(String)savmap.get("OrgnlMsgId"));//原业务报文标识号
			map.put("OrgnlTxId","NONE");//原业务明细业务标识号，查复批量业务、中央对手业务、清算机构借贷业务时填写
			map.put("OrgnlIntrBkSttlmAmt",(String)savmap.get("OrgnlIntrBkSttlmAmt").replace(",","."));//原业务货币符号、金额
			map.put("Rsn",(String)savmap.get("Rsn"));//查复内容
			
			Object[] obj = new Object[1];
			obj[0] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","cipsloginout","loginout",obj);
			Boolean rtnmsg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!rtnmsg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000098"),MdaUtils.getI18NString("qrtmod","CT000099"));
			  return null;
			}
			//获取接口平台返回的内容
			Object[] objs = (Object[])MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+objs[0]);
			return (String)objs[0];
		}
        /**
        *   source:qrtmod.@0028.script
        */
        public String generCips301Message(Map<String,String> savmap)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Map<String,Object> map = new HashMap<String,Object>();

			map.put("MsgId",(String)savmap.get("MsgId"));//报文标识号
			map.put("HMsgRef",(String)savmap.get("Case-OrgnlMsgId"));//报文参考号，取原业务报文标识号
			map.put("HSender","PSBCCNBJXXX");//报文发起方
			map.put("HReceiver",(String)savmap.get("Assgne-MmbId"));//报文接收方
			map.put("HSendDate",(String)savmap.get("HSendDate"));//报文发起日期
			map.put("Tp","cips.301.001.02");//报文类型
			//Assgnr
			Map<String,Object> asrmap = new HashMap<String,Object>();
			asrmap.put("MmbId","PSBCCNBJXXX");//查询直接参与者行号
			if(!MdaUtils.isEmpty(savmap.get("Assgnr-Id")))
			  asrmap.put("Id",(String)savmap.get("Assgnr-Id"));//查询间接参与者行号
			map.put("Assgnr",asrmap);
			//Assgne
			Map<String,Object> asemap = new HashMap<String,Object>();
			asemap.put("MmbId",(String)savmap.get("Assgne-MmbId"));//查复直接参与者行号
			if(!MdaUtils.isEmpty(savmap.get("Assgne-Id")))
			  asemap.put("Id",(String)savmap.get("Assgne-Id"));///查复间接参与者行号
			map.put("Assgne",asemap);
			String dattim = MdaUtils.format(MdaUtils.today(),"yyyy-MM-ddHH:mm:ss");
			map.put("CreDtTm",dattim.substring(0,10)+"T"+dattim.substring(10));//报文发送时间
			//Case
			Map<String,Object> casmap = new HashMap<String,Object>();
			casmap.put("OrgnlMsgId",(String)savmap.get("Case-OrgnlMsgId"));//原业务报文标识号
			casmap.put("OrgnlMmbId",(String)savmap.get("Case-OrgnlMmbId"));//原业务发起直接参与者行号
			map.put("Case",casmap);
			//20201008更新
			map.put("FrTp","cips.301");//原报文类型
			
			String orgtyp = (String)savmap.get("Case-OrgnlTp");
			if("111|112".contains(orgtyp))
			{
			  map.put("OrgnlTp","cips."+orgtyp+".001.02");//原报文类型
			}
			else
			  map.put("OrgnlTp","cips."+orgtyp+".001.01");//原报文类型
			
			//map.put("OrgnlTp",(String)savmap.get("Case-OrgnlTp"));//原报文类型
			map.put("OrgnlTxId","NONE");//原业务明细业务标识号，查复批量业务、中央对手业务、清算机构借贷业务时填写
			map.put("OrgnlIntrBkSttlmAmt",(String)savmap.get("Case-OrgnlIntrBkSttlmAmt").replace(",","."));//原业务货币符号、金额
			map.put("Cntt",(String)savmap.get("Case-Cntt"));//查询内容
			Object[] obj = new Object[1];
			obj[0] = map;
			Object rtn = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","cipsloginout","loginout",obj);
			Boolean rtnmsg = (Boolean)MdaUtils.invoke(rtn,"isSuccess");
			if(!rtnmsg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("qrtmod","CT000100"),MdaUtils.getI18NString("qrtmod","CT000101"));
			  return null;
			}
			//获取接口平台返回的内容
			Object[] data = (Object[])MdaUtils.invoke(rtn,"getContent");//报文内容
			log.debug("{}","return msg："+data[0]);
			return (String)data[0];
		}






















}