package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.bo.Sed;
import com.ceb.gjjs.mda.bo.Mps;
import com.ceb.gjjs.mda.bo.Ser;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.bo.Swepty;
import com.ceb.gjjs.mda.bo.Mpi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Swemod extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Swemod.class);

        //G渠道开始自动报送时间
        private Date rptdattim;

        //G渠道月度报送开始时间
        private Date monrptdat;

        //GISP独立报文存储路径
        private String docpth;

        //报文流
        private IStream msgstm = new StreamImpl();

        //G渠道BIC
        private String bic;

        //报送收报BIC
        private String rptbic;

        //N02报送文件保存路径
        private String n02pth;

        //G渠道报文原文
        private String swemsg;

        //G渠道报文密文
        private String sweencmsg;


        @JsonIgnore
        @BDGetter
        private transient IPanel gispshwp;


	    @BDGetter
		private Swepty swepty;

	    @BDGetter
		private Mps mps;

	    @BDGetter
		private Mpi mpi;

	    @BDGetter
		private Sed sed;

	    @BDGetter
		private Ser ser;

		@BDGetter
		private ModuleList<Sed> sedlst;


		public Swemod()
        {
            super();
            setArgument();
        }

        public Swemod(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }



        /**
        *   source:swemod.@0010.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			/*
			  * 从配置文件读取相关设置信息
			  */
			String propertyPath = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"cfg");
			propertyPath = MdaUtils.catPath(propertyPath,"gisp.properties");

			String bic = Platform.getPropertyValues(propertyPath,"gChannelReportBic");
			this.setBic( bic);

			String rcvbic = Platform.getPropertyValues(propertyPath,"gChannelReportRecvBic");
			this.setRptbic( rcvbic);

			String date = Platform.getPropertyValues(propertyPath,"GispAutoReportDate");
			if(MdaUtils.isEmpty(date))
			{
			  date = "2020-12-01 00:00:00";
			}
			this.setRptdattim( MdaUtils.parseDate(date,"yyyy-MM-dd HH:mm:ss"));

			date = Platform.getPropertyValues(propertyPath,"GispAutoMonthReportDate");
			if(MdaUtils.isEmpty(date))
			{
			  date = "2021-01-01 00:00:00";
			}
			this.setMonrptdat( MdaUtils.parseDate(date,"yyyy-MM-dd HH:mm:ss"));

			this.setDocpth( MdaUtils.getPropertyValue(propertyPath,"GispStorePath"));
			if(MdaUtils.isEmpty(this.getDocpth()))
			{
			  this.setDocpth( "/app/weblogic/data/gisp");
			}
			if(!Platform.mfileExists(this.getDocpth()))
			{
			  Platform.mfileMkdirs(this.getDocpth());
			}

			this.setN02pth( Platform.getPropertyValues(propertyPath,"GispN02StorePath"));
			if(MdaUtils.isEmpty(this.getN02pth()))
			{
			  this.setN02pth( MdaUtils.catPath(this.getDocpth(),"N02"));
			}
			if(!Platform.mfileExists(this.getN02pth()))
			{
			  Platform.mfileMkdirs(this.getN02pth());
			}

			String n02ArcPath = MdaUtils.catPath(this.getN02pth(),"arc");
			if(!Platform.mfileExists(n02ArcPath))
			{
			  Platform.mfileMkdirs(n02ArcPath);
			}
			String n02ErrPath = MdaUtils.catPath(this.getN02pth(),"err");
			if(!Platform.mfileExists(n02ErrPath))
			{
			  Platform.mfileMkdirs(n02ErrPath);
			}

			return true;
        }


        /**
        *   source:swemod.@0000.script
        */
        public boolean checkIsSweBank(String bankCode)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(bankCode))
			  return false;

			String sql = "SELECT INR FROM SWEPTY WHERE COD = '" + bankCode + "' AND VALFLG = 'VLID'";
			Object session = Platform.esdbExecuteSQL("swd",sql);
			Argument<String> inr = new Argument<String>("INR");
			Platform.esdbFetchFields(session,inr);
			int err = ctx.getErrorCode();
			Platform.esdbCloseCursor(session);
			if(err==NO_ERROR)
			{
			  if(!MdaUtils.isEmpty(inr.getValue()))
			  {
			    log.debug("{}","checkIsSweBank:true");
			    return true;
			  }
			}
			log.debug("{}","checkIsSweBank:false");
			return false;
		}
        /**
        *   source:swemod.@0001.script
        */
        public boolean checkIsAllowMessageType(String messageType)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String [] msgTypes = new String[]{"103","202","202COV", "195","196","199","299","900","910","950"};
			for(String msgType : msgTypes)
			{
			  if(msgType.equalsIgnoreCase(messageType) || ("MT " + msgType).equalsIgnoreCase(messageType))
			  {
			    log.debug("{}","checkIsAllowMessageType:true");
			    return true;
			  }
			}

			log.debug("{}","checkIsAllowMessageType:false");
			return false;
		}
        /**
        *   source:swemod.@0002.script
        */
        public boolean gChannelCheck(String sweType, String rcvBnkBic, String actBnkBic)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			///判断是否需要进入SWIFT应急支付渠道。
			///rcvBnkBic: 收报行BIC
			///actBnkBic: 账户行BIC
			log.debug("{}","gChannelCheck:" + sweType + "," + rcvBnkBic + "," + actBnkBic);
			if("S".equals(sweType))
			{
			  log.debug("{}","指定清分渠道为SWIFT");
			  return false;
			}

			boolean isEmergency = true;
			if("E".equals(sweType))
			{
			  log.debug("{}","指定清分渠道为G渠道");
			}
			else if(MdaUtils.isEmpty(sweType) || "A".equals(sweType))
			{
			  log.debug("{}","根据业务要素判断清分渠道");
			  if(!MdaUtils.isEmpty(actBnkBic))
			  {
			    if(!checkIsSweBank(actBnkBic))
			    {
			      log.debug("{}","帐户行不在参与者基础数据中:" + actBnkBic);
			      isEmergency = false;
			    }
			  }

			  if(isEmergency && !MdaUtils.isEmpty(rcvBnkBic))
			  {
			    if(!checkIsSweBank(rcvBnkBic))
			    {
			      log.debug("{}","收报行不在参与者基础数据中:" + rcvBnkBic);
			      isEmergency = false;
			    }
			  }
			}

			return isEmergency;
		}
        /**
        *   source:swemod.@0003.script
        */
        public String genGispRef()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String num = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			String ref = "PSBCG" + num;
			String cnt = MdaUtils.format(Platform.mdbCounter(ref),"0000000");
			ref += cnt;

			return ref;
		}
        /**
        *   source:swemod.@0004.script
        */
        public int checkIsDuplicateReference(String bic, String orgiSendDate, String mesgId)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  // -1流水不存在,0处理失败,1处理成功
			  MdaUtils.clear(this.getSed());
			  Platform.mdbRead(this.getSed(),new Argument("sndnum", mesgId),new Argument("sndbic", bic));
			  if(MdaUtils.isEmpty(this.getSed().getInr()))
			    return -1;
			  else
			  {
			    if(!bic.equals(this.getSed().getSndbic()))
			      return -1;

			    if(!orgiSendDate.equals(MdaUtils.format(this.getSed().getSwedattim(),"yyyyMMdd")))
			      return -1;

			    if("A".equals(this.getSed().getRspsta()))
			    {
			      return 1;
			    }
			    else
			    {
			      return 0;
			    }
			  }
			}
			catch(Exception e)
			{

			}
			return 0;
		}
        /**
        *   source:swemod.@0005.script
        */
        public String removeSf2Tag(String msg, String tag)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			tag = "{" + tag + ":";
			if(msg.contains(tag))
			{
			  String str1 = msg.substring(0, msg.indexOf(tag));
			  String str2 = msg.substring(msg.indexOf(tag));
			  str2 = str2.substring(str2.indexOf("}") + 1);
			  msg = str1 + str2;
			}
			return msg;
		}
        /**
        *   source:swemod.@0006.script
        */
        public String generGispReportC00XmlData(String bic)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Map<String,String> bicMap = new HashMap();
			String sql = " SELECT extkey,chnnam,engnam from pty where status = '0' and ptytyp like '%T%'";
			Platform.setDefaultDB("swd");
			int error = ctx.getErrorCode();
			Platform.mdbExecuteSQL(sql);
			error = ctx.getErrorCode();
			StringBuilder sb = new StringBuilder();
			sb.append("<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"yes\"?>").append("\r\n");
			sb.append("<Document xmlns=\"dat.004.01\">").append("\r\n");
			sb.append("<MSG>").append("\r\n");
			while(true)
			{
			  Argument<String> extkey = new Argument("extkey");
			  Argument<String> chnnam = new Argument("chnnam");
			  Argument<String> engnam = new Argument("engnam");
			  Platform.mdbFetchFields(extkey,chnnam,engnam);
			  error = ctx.getErrorCode();
			  if(error != NO_ERROR)
			  {
			    break;
			  }
			  if(MdaUtils.isEmpty(extkey.getValue()))
			  {
			    continue;
			  }
			  if(bicMap.containsKey(extkey.getValue()))
			  {
			    continue;
			  }
			  sb.append("	<INFO>").append("\r\n");
			  sb.append("		<SENDERBIC>").append(bic).append("</SENDERBIC>").append("\r\n");
			  sb.append("		<RECEIVERBIC>").append(extkey.getValue()).append("</RECEIVERBIC>").append("\r\n");
			  sb.append("		<RECEIVERLEI>").append(engnam.getValue()).append("</RECEIVERLEI>").append("\r\n");
			  if("BKCHCNBJ110".equalsIgnoreCase(extkey.getValue()) || "ICBKCNBJBJM".equalsIgnoreCase(extkey.getValue())
			    || "PCBCCNBJXXX".equalsIgnoreCase(extkey.getValue()) || "SPDBCNSHXXX".equalsIgnoreCase(extkey.getValue()))
			  {
			    sb.append("		<CHANNEL>").append("01|03|").append("</CHANNEL>").append("\r\n");
			  }
			  else
			  {
			    sb.append("		<CHANNEL>").append("01|").append("</CHANNEL>").append("\r\n");
			  }
			  sb.append("		<STATE>").append("ACTIVE").append("</STATE>").append("\r\n");
			  sb.append("	</INFO>").append("\r\n");

			  bicMap.put(extkey.getValue(),extkey.getValue());
			}
			Platform.mdbCloseCursor();
			sb.append("</MSG>").append("\r\n");
			sb.append("</Document>");
			return sb.toString();
		}
        /**
        *   source:swemod.@0008.script
        */
        public String getStoreFileFullPathName(String dir, String fileName, String fileType)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(fileName==null||fileType==null) return null;
			else
			{
			  return MdaUtils.catPath(dir,fileName.substring(0,4)+"/"+fileName+"." + fileType);
			}
		}
        /**
        *   source:swemod.@0009.script
        */
        public String getGispReportType(String msgtyp, String subtyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String reportType = null;
			if(MdaUtils.isEmpty(msgtyp) || MdaUtils.isEmpty(subtyp))
			  return reportType;
			if("sf2".equals(msgtyp))
			{
			  if("103".equals(subtyp) || "202".equals(subtyp) || "202COV".equalsIgnoreCase(subtyp)|| "205".equals(subtyp))
			  {
			    reportType = "P01";
			  }
			  else
			  {
			    reportType = "N01";
			  }
			}
			else if("txt".equals(msgtyp))
			{
			  reportType = "P03";
			}

			return reportType;
		}
        /**
        *   source:swemod.@0012.script
        */
        public boolean generGisp940WithoutMps(String serInr, String rptType, String bic,String xml)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getSed());
			String inr = Platform.sdbCounter(this.getSed());
			//String xmlFileName = inr + ".xml";
			String filePath = getStoreFileFullPathName(this.getDocpth(), inr,"xml");
			IStream is = this.getMsgstm();
			MdaUtils.streamClear(is);
			Platform.convertString2IStream(xml,is);
			Platform.mstreamSave(is,filePath);

			Map<String,Object> map = new HashMap();
			map.put("MesgType","gisp.940.001.01");
			map.put("OrigSender", this.getBic());
			map.put("OrigReceiver", this.getRptbic());
			Date now = MdaUtils.today();
			String origSendDate = MdaUtils.format(now,"yyyyMMdd");
			String origSendTime = MdaUtils.format(now,"HHmmss");
			String mesgId = genGispRef();
			map.put("OrigSendDate",origSendDate);
			map.put("OrigSendTime",origSendTime);
			map.put("MesgID",mesgId);
			map.put("MesgRefID", "NONE");
			map.put("Ref",serInr);
			map.put("Tp", rptType);
			map.put("InstgPty", this.getBic());
			map.put("InstdPty", this.getRptbic());
			map.put("MsgCntt", xml);
			log.debug("{}","SWE报文组装要素:");
			log.debug("{}",map);

			Object[] arg = new Object[1];
			arg[0] = map;
			Object object = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","gispmsgtogisp","msgtogisp",arg);
			if(object == null)
			{
			  return false;
			}
			Boolean result = (Boolean)MdaUtils.invoke(object,"isSuccess");
			if(!result)
			{
			  log.error("{}","组报失败");
			  return false;
			}
			Object[] contents = (Object[])MdaUtils.invoke(object,"getContent");
			String gispSendMessage = (String)contents[0];//组好的密文报文
			log.debug("{}","SWE密文报文:"+gispSendMessage);
			String gispSaveMessage = (String)contents[1];//组好的明文报文
			gispSaveMessage = gispSaveMessage.replaceAll("&lt;","<").replaceAll("&gt;",">");
			log.debug("{}","SWE明文报文:"+ gispSaveMessage);

			IStream ms = this.getMsgstm();
			String saveFilePath = filePath.replace(".xml",".gisp940");
			log.debug("{}","保存SWE明文:" + saveFilePath);
			MdaUtils.streamClear(ms);
			Platform.convertString2IStream(gispSaveMessage,ms);
			Platform.mstreamSave(ms,saveFilePath);

			///保存要发送的密文
			String sendFilePath = filePath.replace(".xml",".gisp940x");
			log.debug("{}","保存SWE密文:" + sendFilePath);
			MdaUtils.streamClear(ms);
			Platform.convertString2IStream(gispSendMessage,ms);
			Platform.mstreamSave(ms,sendFilePath);

			Platform.mdbBegin();
			int error = ctx.getErrorCode();
			this.getSed().setInr( inr);
			this.getSed().setDir( "<");
			this.getSed().setMsgtyp( "940");
			this.getSed().setSndbic( this.getBic());
			this.getSed().setRcvbic( this.getRptbic());
			this.getSed().setSndnum( mesgId);
			this.getSed().setRefnum( serInr);
			this.getSed().setMsgref( serInr);
			this.getSed().setRcvdattim( now);
			this.getSed().setSttdattim( now);
			this.getSed().setSndsta( "W");
			this.getSed().setAcksta( "X");
			this.getSed().setRspsta( "X");
			this.getSed().setSta( "W");
			this.getSed().setRpttyp( rptType);
			this.getSed().setSwedattim( now);
			this.getSed().setLstdattim( now);
			this.getSed().setSnddattim( now);
			Platform.mdbInsert(this.getSed());
			if(ctx.getErrorCode() != NO_ERROR)
			{
			  Platform.mdbRollback();
			  return false;
			}

			Platform.mdbCommit();
			return true;
		}
        /**
        *   source:swemod.@0013.script
        */
        public String[] getAvailableCipsqz()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String[] rtn = new String[2];
			String[] ips = null;
			String[] ip1 = null;
			String[] ip2 = null;
			String sql = "SELECT ip FROM fipsta WHERE chncod='CIPS' and status='true' ";
			Argument<String> ip = new Argument<String>("ip");
			ctx.getErrorCode();
			Object session = Platform.esdbExecuteSQL("fxd",sql);
			Platform.esdbFetchFields(session,ip);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  String str1 = ip.value;
			  ips= str1.split(";");
			  ip1= ips[0].split(":");
			  ip2= ips[1].split(":");
			}
			Platform.esdbCloseCursor(session);
			rtn[0]=(String)MdaUtils.invoke("cn.com.brilliance.psbc.cache.checkSocketAvailable","checkSocketAvail",ip1[0],ip2[0],ip1[1]);
			rtn[1] = ip1[1];
			return rtn;
		}
        /**
        *   source:swemod.@0014.script
        */
        public boolean sendGisp940(String sedInr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String fileName = sedInr + ".xml";
			String filePath = getStoreFileFullPathName(this.getDocpth(), sedInr,"gisp940x");
			if(!MdaUtils.fileExists(filePath))
			{
			  //调用接口平台或JAVA方法获取文件服务器上;对应目录的文件
			  log.debug("{}","getMessageFromFileServer:" + filePath);
			  if(MdaUtils.isEmpty(ctx.absGet(Sysmod.class).getMessageFromFileTransfer(filePath)))
			  {
			    log.error("{}","报文文件不存在:" + filePath);
			    return false;
			  }
			}
			IStream is = this.getMsgstm();
			MdaUtils.streamClear(is);
			Platform.mstreamLoad(is,filePath);
			String msg = Platform.convertIStream2String(is);
			log.debug("{}","读取报文文件内容:" + filePath + ",准备上送接口平台生成应急支付940报文");

			log.debug("{}","待发送报文==="+msg);
			Object[] arg = new Object[3];
			arg[0] = msg;
			//获取电证前置机信息
			String[] strs = getAvailableGispQz();
			if(strs == null || strs.length != 2)
			  return false;
			arg[1] = strs[0];
			arg[2] = strs[1];
			log.debug("{}","可用前置机地址："+arg[1]+":"+arg[2]);
			Object object = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","cipssndtoptms","sndtoptms",arg);
			Boolean result = (Boolean)MdaUtils.invoke(object,"isSuccess");
			if(!result)
			{
			  log.error("{}","发报失败");
			  return false;
			}

			return true;
		}
        /**
        *   source:swemod.@0015.script
        */
        public String getRate(int fulchncnt, int cnt)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(cnt <= 0)
			  return "0.00";

			BigDecimal a = new BigDecimal(fulchncnt);
			BigDecimal b = new BigDecimal(cnt);
			BigDecimal c = a.divide(b,4,java.math.RoundingMode.HALF_DOWN).multiply(BigDecimal.valueOf(100));
			return c.setScale(2,java.math.RoundingMode.HALF_DOWN).toPlainString();
		}
        /**
        *   source:swemod.@0016.script
        */
        public List<CodetableItem> getGispMessageTypeCodetable()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<CodetableItem> list = new ArrayList<CodetableItem>();
			list.add(new CodetableItem("MT 199","MT 199"));
			list.add(new CodetableItem("MT 202COV","MT 202COV"));
			list.add(new CodetableItem("MT 900","MT 900"));
			list.add(new CodetableItem("MT 910","MT 910"));
			list.add(new CodetableItem("MT 950","MT 950"));
			return list;
		}
        /**
        *   source:swemod.@0017.script
        */
        public List<CodetableItem> getGispMessageSimpleTypeCodetable()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<CodetableItem> list = new ArrayList<CodetableItem>();
			list.add(new CodetableItem("199","199"));
			list.add(new CodetableItem("202COV","202COV"));
			list.add(new CodetableItem("900","900"));
			list.add(new CodetableItem("910","910"));
			list.add(new CodetableItem("950","950"));
			return list;
		}
        /**
        *   source:swemod.@0018.script
        */
        public String getSf2DomainValue(String msg, String tag)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			tag = "{" + tag + ":";
			if(msg.contains(tag))
			{
			  String str1 = msg.substring(msg.indexOf(tag) + tag.length());
			  return str1.substring(0, str1.indexOf("}"));
			}
			return null;
		}
        /**
        *   source:swemod.@0019.script
        */
        public String handleGispReceiveSf2Message(String sf2Msg, String orgiSendDate, String orgiSendTime)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","handleGispReceiveSf2Message:" + sf2Msg);
			if(MdaUtils.isEmpty(sf2Msg))
			  return sf2Msg;

			String basicHeader = getSf2DomainValue(sf2Msg,"1");
			log.debug("{}","basicHeader:" + basicHeader);
			String appHeader = getSf2DomainValue(sf2Msg,"2");
			log.debug("{}","appHeader:" + appHeader);
			if(!MdaUtils.isEmpty(appHeader) && appHeader.length() != 47)
			{
			  String newBasicHeader = createSf2BasicHeader(basicHeader, appHeader);
			  String newAppHeader = createSf2ApplicationHeader(basicHeader, appHeader, orgiSendDate, orgiSendTime);
			  sf2Msg = sf2Msg.replace(basicHeader, newBasicHeader);
			  sf2Msg = sf2Msg.replace(appHeader, newAppHeader);
			}

			if(sf2Msg.contains("{2:I"))
			{
			  sf2Msg = sf2Msg.replace("{2:I","{2:O");
			}

			if(sf2Msg.contains("N 999"))
			{
			  sf2Msg = sf2Msg.replace("N 999","N");
			}
			return sf2Msg;
		}
        /**
        *   source:swemod.@0020.script
        */
        public String createSf2ApplicationHeader(String basicHeader, String appHeader, String orgiSendDate, String orgiSendTime)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  log.debug("{}","createSf2ApplicationHeader");

			  Date now = MdaUtils.today();
			  String msgType = appHeader.substring(0,4);
			  String bic = basicHeader.substring(3,15);
			  String priority = appHeader.substring(16,17);
			  String recvDate = MdaUtils.format(now,"yyMMdd");
			  String recvTime = MdaUtils.format(now,"HHmm");
			  if(!MdaUtils.isEmpty(orgiSendDate))
			  {
			    if(orgiSendDate.length() == 8)
			    {
			      orgiSendDate = orgiSendDate.substring(2);
			    }
			  }
			  else
			  {
			    orgiSendDate = recvDate;
			  }
			  if(!MdaUtils.isEmpty(orgiSendTime))
			  {
			    if(orgiSendTime.length() == 6)
			    {
			      orgiSendTime = orgiSendTime.substring(0,4);
			    }
			  }
			  else
			  {
			    orgiSendTime = recvTime;
			  }
			  String seq = "0000000000";
			  if(!MdaUtils.isEmpty(basicHeader) && basicHeader.length() >= 25)
			  {
			    seq = basicHeader.substring(15,25);
			  }

			  String newAppHeader = msgType + orgiSendTime + orgiSendDate + bic + seq + recvDate + recvTime + priority;
			  log.debug("{}","createSf2ApplicationHeader:" + newAppHeader);
			  return newAppHeader;
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			  return appHeader;
			}
		}
        /**
        *   source:swemod.@0021.script
        */
        public void createOrUpdateSedEntryForCips(String subtyp,com.ceb.gjjs.mda.bo.Mps mps,com.ceb.gjjs.mda.bo.Mpi mpi)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  if(!MdaUtils.isEmpty(subtyp)&&("111|112|113".contains(subtyp)))
			  {
			    Platform.setDefaultDB("swd");
			    Platform.mdbBegin();
			    MdaUtils.clear(this.getSed());
			    Platform.mdbRead(this.getSed(),new Argument("mpsinr",mps.getInr()).and("msgtyp","940"));
			    int error = ctx.getErrorCode();
			    this.getSed().setMpsinr( mps.getInr());
			    this.getSed().setSmhinr( mps.getSmhinr());
			    this.getSed().setDir( "<");
			    this.getSed().setMsgdir( mpi.getDir());
			    this.getSed().setMsgtyp( "940");
			    this.getSed().setSubmsgtyp( "CIPS");
			    this.getSed().setSubtyp( mpi.getSubtyp());
			    this.getSed().setOwnref( mpi.getOwnref());
			    this.getSed().setOthref( mpi.getOthref());
			    this.getSed().setCur( mpi.getCur());
			    this.getSed().setAmt( mpi.getAmt());
			    this.getSed().setSndbic( mpi.getSndbic());
			    this.getSed().setRcvbic( mpi.getRcvbic());
			    this.getSed().setActbic( mpi.getActbic());
			    this.getSed().setAccdat( mpi.getAccdat());
			    this.getSed().setRcvdattim( mps.getRcvdattim());
			    this.getSed().setLstdattim( this.getMps().getLstdattim());
			    this.getSed().setSndsta( "X");
			    this.getSed().setRspsta( "X");
			    this.getSed().setAcksta( "X");
			    this.getSed().setSta( "D");
			    this.getSed().setRpttyp( "");
			    String mmbid = null;
			    if("<".equals(mpi.getDir()))
			    {
			      //往账判断收款人银行
			      mmbid = mpi.getRecbic();
			    }
			    else
			    {
			      mmbid = mpi.getPaybic();
			    }
			    log.debug("{}","createOrUpdateSedEntryForCips mmbid = " + mmbid);
			    if(!MdaUtils.isEmpty(mmbid))
			    {
			      log.debug("{}","mmbid country = " + mmbid.substring(4,6));
			    }
			    if(!MdaUtils.isEmpty(mmbid) && "CN".equalsIgnoreCase(mmbid.substring(4,6)))
			    {
			      this.getSed().setFulchn("X");
			    }
			    else
			    {
			      this.getSed().setFulchn("");
			    }
			    if(error == 228)
			    {
			      Platform.sdbInsert(this.getSed());
			    }
			    else
			    {
			      Platform.mdbUpdate(this.getSed());
			    }
			    Platform.mdbCommit();
			    error = ctx.getErrorCode();
			  }
			  else
			  {
			    log.debug("{}","Ignore create sed entry for cips:" + subtyp);
			  }
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			  e.printStackTrace();
			}
			finally
			{
			  Platform.setDefaultDB("fxd");
			}
		}
        /**
        *   source:swemod.@0022.script
        */
        public String createSf2BasicHeader(String basicHeader, String appHeader)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			try
			{
			  log.debug("{}","createSf2BasicHeader");

			  String sndbic = basicHeader.substring(3,15);
			  String rcvbic = appHeader.substring(4,16);

			  String flag = rcvbic.substring(8);
			  if(!"AXXX".equals(flag))
			  {
			    rcvbic = rcvbic.replace(flag,"AXXX");
			  }

			  String newBasicHeader = basicHeader.replace(sndbic,rcvbic);
			  log.debug("{}","createSf2BasicHeader:" + newBasicHeader);
			  return newBasicHeader;
			}
			catch(Exception e)
			{
			  log.error("{}",e);
			  return appHeader;
			}
		}
        /**
        *   source:swemod.@0023.script
        */
        public boolean updateSedEntryInformation(com.ceb.gjjs.mda.bo.Mps mps, com.ceb.gjjs.mda.bo.Mpi mpi)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","updateSedEntryInformation");
			MdaUtils.clear(this.getSedlst());
			Platform.mdbReadset(this.getSedlst(),new Argument("mpsinr",mps.getInr()));
			log.debug("{}","sedlst size:" + this.getSedlst().size());
			int error = ctx.getErrorCode();
			if(this.getSedlst().size() > 0)
			{
			  for(com.ceb.gjjs.mda.bo.Sed sed : this.getSedlst())
			  {
			    sed.setOwnref( mpi.getOwnref());
			    sed.setOthref( mpi.getOthref());
			    sed.setCur( mpi.getCur());
			    sed.setAmt( mpi.getAmt());
			    sed.setActbic( mpi.getActbic());
			    sed.setAct( mpi.getAct());
			    sed.setAccdat( mpi.getAccdat());
			    Platform.mdbUpdate(sed);
			    if(ctx.getErrorCode() != NO_ERROR)
			      return false;
			  }
			}
			return true;
		}
        /**
        *   source:swemod.@0024.script
        */
        public String[] getAvailableGispQz()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String[] rtn = new String[2];
			String[] ips = null;
			String[] ip1 = null;
			String[] ip2 = null;
			String sql = "SELECT ip FROM fipsta WHERE chncod='GISP' and status='true' ";
			Argument<String> ip = new Argument<String>("ip");
			ctx.getErrorCode();
			Object session = Platform.esdbExecuteSQL("fxd",sql);
			Platform.esdbFetchFields(session,ip);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  String str1 = ip.value;
			  ips= str1.split(";");
			  ip1= ips[0].split(":");
			  ip2= ips[1].split(":");
			}
			Platform.esdbCloseCursor(session);
			rtn[0]=(String)MdaUtils.invoke("cn.com.brilliance.psbc.cache.checkSocketAvailable","checkSocketAvail",ip1[0],ip2[0],ip1[1]);
			rtn[1] = ip1[1];
			return rtn;
		}
        /**
        *   source:swemod.@0025.script
        */
        public String generGispReportN02XmlData(String source,String type,String sender, long totcnt)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			StringBuilder sb = new StringBuilder();
			sb.append("<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"yes\"?>").append("\r\n");
			sb.append("<Document xmlns=\"dat.003.01\">").append("\r\n");
			sb.append("<MSG_HEADER>").append("\r\n");
			sb.append("		<DATASOURCE>").append(source).append("</DATASOURCE>").append("\r\n");
			sb.append("		<BUSINESSTYPE>").append(type).append("</BUSINESSTYPE>").append("\r\n");
			sb.append("		<SENDER>").append(sender).append("</SENDER>").append("\r\n");
			sb.append("		<TOTALNUMBER>").append(totcnt).append("</TOTALNUMBER>").append("\r\n");
			sb.append("</MSG_HEADER>").append("\r\n");
			sb.append("</Document>");
			return sb.toString();
		}
        /**
        *   source:swemod.@0027.script
        */
        public boolean generAndSendGisp991()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Platform.setDefaultDB("swd");
			Map<String,Object> map = new HashMap();
			map.put("MesgType","gisp.991.002.01");
			map.put("OrigSender", this.getBic());
			map.put("OrigReceiver", this.getBic());
			Date now = MdaUtils.today();
			String origSendDate = MdaUtils.format(now,"yyyyMMdd");
			String origSendTime = MdaUtils.format(now,"HHmmss");
			String mesgId = genGispRef();
			map.put("OrigSendDate",origSendDate);
			map.put("OrigSendTime",origSendTime);
			map.put("MesgID",mesgId);
			map.put("MesgRefID", "NONE");
			log.debug("{}","SWE报文组装991报文要素:");
			log.debug("{}",map);

			Object[] arg = new Object[1];
			arg[0] = map;
			Object object = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","gispmsgtogisp","msgtogisp",arg);
			if(object == null)
			{
			  return false;
			}
			Boolean result = (Boolean)MdaUtils.invoke(object,"isSuccess");
			if(!result)
			{
			  log.error("{}","组报失败");
			  return false;
			}
			Object[] contents = (Object[])MdaUtils.invoke(object,"getContent");
			String msg = (String)contents[0];//组好的报文
			log.debug("{}","SWE报文:"+msg);

			MdaUtils.clear(this.getSed());
			String inr = Platform.sdbCounter(this.getSed());
			String filePath = getStoreFileFullPathName(this.getDocpth(), inr, "gisp991");
			IStream ms = this.getMsgstm();
			log.debug("{}","保存gisp991:" + filePath);
			MdaUtils.streamClear(ms);
			Platform.convertString2IStream(msg,ms);
			Platform.mstreamSave(ms,filePath);

			log.debug("{}","待发送991报文==="+msg);
			arg = new Object[3];
			arg[0] = msg;
			//获取电证前置机信息
			String[] strs = getAvailableGispQz();
			if(strs == null || strs.length != 2)
			  return false;
			arg[1] = strs[0];
			arg[2] = strs[1];
			log.debug("{}","可用前置机地址："+arg[1]+":"+arg[2]);
			object = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","cipssndtoptms","sndtoptms",arg);
			result = (Boolean)MdaUtils.invoke(object,"isSuccess");
			if(!result)
			{
			  log.error("{}","发报失败");
			  return false;
			}

			Platform.mdbBegin();
			int error = ctx.getErrorCode();
			this.getSed().setInr( inr);
			this.getSed().setDir( "<");
			this.getSed().setMsgtyp( "991");
			this.getSed().setSndbic( this.getBic());
			this.getSed().setRcvbic( this.getBic());
			this.getSed().setSndnum( mesgId);
			this.getSed().setRcvdattim( now);
			this.getSed().setSttdattim( now);
			this.getSed().setSndsta( "A");
			this.getSed().setAcksta( "X");
			this.getSed().setRspsta( "X");
			this.getSed().setSta( "D");
			this.getSed().setSwedattim( now);
			this.getSed().setLstdattim( now);
			this.getSed().setSnddattim( now);
			Platform.mdbInsert(this.getSed());
			if(ctx.getErrorCode() != NO_ERROR)
			{
			  Platform.mdbRollback();
			  return false;
			}

			Platform.mdbCommit();
			return true;
		}

























}